@@ -71,9 +71,15 @@ class AmazonResourceProvider(ResourceProvider):
         # Close all open HTTP connections
         aws_close_dfr = self._aws_client.close()
         img_close_dfr = self._img_client.close()
-        return defer.DeferredList([aws_close_dfr, img_close_dfr],
+        dfr = defer.DeferredList([aws_close_dfr, img_close_dfr],
                                   consumeErrors=True)
 
+        def parent_clean(result):
+            return super(AmazonResourceProvider, self).clean()
+
+        dfr.addCallback(parent_clean)
+        return dfr
+
     def get(self, uri, context_model=None):
         """
         GET request to the Amazon servers.
