@@ -29,6 +29,7 @@ from elisa.plugins.amazon.models import AmazonItemModel, AmazonItemListModel
 from elisa.plugins.amazon.key import AWS_KEY
 
 from elisa.plugins.base.models.media import RawDataModel
+from elisa.core.utils.misc import run_functional_tests_check
 
 from elisa.core.media_uri import MediaUri
 
@@ -41,6 +42,7 @@ class TestAmazonResourceProvider(TestCase):
     """
 
     def setUp(self):
+        run_functional_tests_check()
         def created(provider):
             self.provider = provider
             return provider.initialize()
