@@ -162,11 +162,12 @@ class Master(object):
         slave = Slave(cookie)
         # FIXME: detect when running under py2exe
         # the command line used to run the slaves
-        if os.path.basename(sys.executable) == 'elisa.exe':
+        if hasattr(sys, 'frozen'):
             executable = os.path.join(os.path.dirname(sys.executable),
                     'deps', 'bin', 'elisa_fork.exe')
         else:
             executable = sys.executable
+
         args = [executable, self._slave_script, self._slave_runner,
                 ":".join(self._real_address), 'Slave-%s' % cookie]
 
