@@ -17,12 +17,13 @@
 # Author: Philippe Normand <philippe@fluendo.com>
 
 """
-Resource provider being able to list UPnP services
+Resource provider able to list UPnP services.
 """
 
 from twisted.internet import defer, task
 
 from coherence import __version_info__ as coherence_version
+from coherence.base import Coherence
 
 if coherence_version < (0, 5, 8):
     import louie
@@ -35,14 +36,12 @@ from elisa.core.components.resource_provider import ResourceProvider
 
 from elisa.core.components.model import Model
 
-from elisa.core.application import ComponentsLoadedMessage
 from elisa.plugins.base.models.network import NetworkServiceModel
 from elisa.plugins.base.messages.network import NetworkServiceAppearedMessage
 from elisa.plugins.base.messages.network import NetworkServiceDisappearedMessage
 
-from elisa.plugins.coherence.coherence_device_message import CoherenceDeviceMessage
-
 class CoherenceResource(ResourceProvider):
+
     """
     The Coherence resource_provider is in charge of detecting UPnP
     services available on the local network. It currently only detects
@@ -63,21 +62,21 @@ class CoherenceResource(ResourceProvider):
     _known_media_servers = {}
 
     def initialize(self):
-        common.application.bus.register(self._bus_message_received,
-                                        ComponentsLoadedMessage)
+        coherence_config = {'logmode': 'none',
+                            'controlpoint': 'yes',
+                            'plugins': {}}
+        try:
+            coherence_instance = Coherence(coherence_config)
+        except:
+            return defer.fail()
+
+        louie.connect(self._detected_media_server,
+                    'Coherence.UPnP.ControlPoint.MediaServer.detected', louie.Any)
+        louie.connect(self._removed_media_server,
+                'Coherence.UPnP.ControlPoint.MediaServer.removed', louie.Any)
+
         return defer.succeed(self)
 
-    def _bus_message_received(self, msg, sender):
-        msg = CoherenceDeviceMessage('Coherence.UPnP.ControlPoint.MediaServer.detected',
-                                     self._detected_media_server,
-                                     louie.Any)
-        common.application.bus.send_message(msg)
-
-        msg = CoherenceDeviceMessage('Coherence.UPnP.ControlPoint.MediaServer.removed',
-                                     self._removed_media_server,
-                                     louie.Any)
-        common.application.bus.send_message(msg)
-
     def _detected_media_server(self, client, udn):
         device = client.device
 
