@@ -20,6 +20,7 @@
 parse the result from the typefinder and wrap it into the database
 """
 
+from elisa.plugins.database.video_parser import VideoParser
 from elisa.plugins.database.models import Artist, MusicAlbum, MusicTrack, \
     File, Tag, Image, PhotoAlbum, Video, \
     PICTURES_SECTION, MUSIC_SECTION, VIDEO_SECTION
@@ -36,7 +37,11 @@ import time, pkg_resources, datetime, os, re
 general_keys = ['file_type', 'mime_type']
 # metadata specific to gstreamer. currently the API of gst metadata requires that we
 # specify all the gstreamer metadata we might want to have...
-audio_keys = ['artist', 'album', 'song', 'duration', 'genre', 'track', 'date']
+audio_keys = ['artist', 'album', 'song', 'duration', 'genre', 'track', 'date'
+             # these keys are for Windows Media Files
+             'WM/AlbumArtist', 'WM/AlbumTitle', 'WM/Year', 'WM/TrackNumber',
+             'title'
+            ]
 image_keys = ['date-time-original', 'date-time-modified', 'date-time-digitized',\
         'capture-flash', 'capture-orientation', 'gps-altitude', 'date-time', 
         'gps-latitude', 'gps-longitude']
@@ -44,12 +49,9 @@ image_keys = ['date-time-original', 'date-time-modified', 'date-time-digitized',
 all_keys = audio_keys + image_keys + general_keys
 global_request_dict = dict( [ (key, None) for key in all_keys ] )
 
-
-
 class StopProcessing(Exception): pass
 
 class DatabaseParser(Component):
-    
     entry_point = 'elisa.plugins.database.processors'
     image_date_splitter = re.compile(r'[^0-9]+')
 
@@ -64,13 +66,15 @@ class DatabaseParser(Component):
 
     def __init__(self):
         super(DatabaseParser, self).__init__()
-        self.store = None
+        self._store = None
         self.metadata = None
         self._processors = []
 
         self._commit_delay = None
         self._commit_counter = 0
 
+        self._video_parser = VideoParser()
+
     def initialize(self):
         def set_metadata(metadata):
             self.metadata = metadata
@@ -87,7 +91,8 @@ class DatabaseParser(Component):
                     self.between_process_delay)
 
             return result
-           
+
+
         dfr = super(DatabaseParser, self).initialize()
         dfr.addCallback(self.load_processors)
         dfr.addCallback(create_client)
@@ -95,6 +100,15 @@ class DatabaseParser(Component):
         dfr.addCallback(self._reset_autocommit_delay)
         return dfr
 
+    def _set_store(self, store):
+        self._store = store
+        self._video_parser.store = store
+
+    def _get_store(self):
+        return self._store
+
+    store = property(fget=_get_store, fset=_set_store)
+
     def load_processors(result, self):
 
         def failed(failure, name):
@@ -392,22 +406,27 @@ class DatabaseParser(Component):
     def parse_into_track(self, track, metadata):
         self.debug("parsing music track %s" % track.file_path)
 
-        tags = ( ('song', 'title', unicode),
-                 ('track', 'track_number', int),
+        tags = [ ('song', 'title', unicode),
                  ('genre', 'genre', unicode),
                  ('duration', 'duration', float),
-               )
+                 ('track', 'track_number', int),
+               ]
+
+        # stupid WMA 
+        if metadata.get('song', None) is None:
+            tags.append( ('title', 'title', unicode) )
+           
+        if metadata.get('track', None) is None:
+            tags.append ( ('WM/TrackNumber', 'track_number', int) )
         
         self.parse_metadata_into_model(track, metadata, tags)
 
-        try: 
-            album_name = metadata['album']
-            if album_name:
-                album_name = unicode(album_name)
-        except KeyError:
-            album_name = None
+        album_name = metadata.get('album') or metadata.get('WM/AlbumTitle')
+        if album_name:
+            album_name = unicode(album_name)
 
-        date = metadata.get('date', None)
+        date = metadata.get('date')
+        wm_year = metadata.get('WM/Year')
 
         track.album_name = album_name
 
@@ -416,14 +435,16 @@ class DatabaseParser(Component):
 
         if album_name:
             # make sure the album exists
-            if date:
+            if date is not None:
                 # and has the right date set
                 date = datetime.datetime.fromtimestamp(date)
+            elif wm_year is not None:
+                date = datetime.datetime(int(wm_year), 1, 1)
 
             dfr.addCallback(self.make_sure_of_music_album, \
                             album_name, release_date=date)
 
-        artists = metadata.get('artist', None)
+        artists = metadata.get('artist') or metadata.get('WM/AlbumArtist')
         if artists:
             if isinstance(artists, basestring):
                 artists = [artists]
@@ -433,17 +454,19 @@ class DatabaseParser(Component):
     # the case of videos
     def parse_into_video(self, video, metadata):
         self.debug("parsing video %s" % video.file_path)
-        
+
         # We'll use the filename as video name until we can get a proper name
         video.name = os.path.basename(video.file_path)
-        
+
         # We set the creation time as the date of the file
         stamp = os.stat(video.file_path).st_mtime
         video.creation_time = datetime.datetime.fromtimestamp(stamp)
-        
-        if 'duration' in metadata:
+
+        if 'duration' in metadata and metadata['duration']:
             video.duration = int(metadata['duration'])
-        
+
+        return self._video_parser.parse(video)
+
     # the case of images
     def parse_into_image(self, image, metadata):
         self.debug("parsing image %s" % image.file_path)
