@@ -27,7 +27,12 @@ from elisa.core import common
 from elisa.core.media_uri import MediaUri
 from elisa.core.log import getFailureMessage
 from elisa.core.components.service_provider import ServiceProvider
-from elisa.core.application import ComponentsLoadedMessage, PICTURES_CACHE
+from elisa.core.default_config import PICTURES_CACHE
+
+try:
+    from elisa.plugins.pigment.message import PigmentFrontendLoadedMessage
+except ImportError:
+    PigmentFrontendLoadedMessage = None
 
 from elisa.plugins.poblesec.music_library import album_cover_retriever
 
@@ -201,32 +206,24 @@ class MusicImpl(object):
         def get_uri(album):
             return album.cover_uri
 
-        def get_album_cover_uri(album):
+        def get_album_cover_uri(album, artist):
             if album.cover_uri:
                 return album.cover_uri
 
             # album_cover_retriever.get_cover_uri() returns an Album [sic!]
-            dfr = album_cover_retriever.get_cover_uri(album, artist_name)
+            dfr = album_cover_retriever.get_cover_uri(album, artist.name)
             dfr.addCallback(get_uri)
 
             return dfr
 
         def find_cover_art(artist):
             if artist is None:
-                # Try to find the album directly by name.  Not very reliable,
-                # and not very frequently needed, but it's better than no art?
-                # Especially if we want to preseed database with album art,
-                # we need this fallback.
-                dfr = common.application.store.find(MusicAlbum, MusicAlbum.name == album_name)
-                dfr.addCallback(result_set_one)
-                dfr.addCallback(get_album_cover_uri)
-                dfr.addCallback(self._get_cover_thumbnail)
-                return dfr
+                raise ArtistNotFoundError()
 
             dfr = artist.tracks.find(MusicTrack.album_name == album_name)
             dfr.addCallback(result_set_any)
             dfr.addCallback(get_album)
-            dfr.addCallback(get_album_cover_uri)
+            dfr.addCallback(get_album_cover_uri, artist)
             dfr.addCallback(self._get_cover_thumbnail)
 
             return dfr
@@ -450,10 +447,16 @@ class DatabaseDBusServiceProvider(ServiceProvider):
 
     def _start_dbus(self):
         bus = dbus.SessionBus()
-
+        
+        # get known names
+        self.bus_name = \
+                dbus.service.BusName('com.fluendo.Elisa', bus)
+    
         # create the objects we export
-        self.photo = Photo(bus, '/com/fluendo/Elisa/Plugins/Database/Photo')
-        self.music = Music(bus, '/com/fluendo/Elisa/Plugins/Database/Music')
+        self.photo = Photo(bus, '/com/fluendo/Elisa/Plugins/Database/Photo',
+                self.bus_name)
+        self.music = Music(bus, '/com/fluendo/Elisa/Plugins/Database/Music',
+                self.bus_name)
 
     def _stop_dbus(self):
         bus = dbus.SessionBus()
@@ -463,16 +466,20 @@ class DatabaseDBusServiceProvider(ServiceProvider):
         self.music.remove_from_connection(bus,
                 '/com/fluendo/Elisa/Plugins/Database/Music')
 
-    def _register_player_status_changes(self):
-        bus = common.application.bus
-        bus.register(self._components_loaded, ComponentsLoadedMessage)
+        # BusName implements __del__, eew
+        del self.bus_name
 
-    def _components_loaded(self, msg, sender):
-        # FIXME: we need an API to retrieve the frontend
-        frontends = common.application.interface_controller.frontends
-        frontend = frontends.values()[0]
-        controllers = frontend.retrieve_controllers('/poblesec') 
-        poblesec = controllers[0]
+    def _register_player_status_changes(self):
+        if PigmentFrontendLoadedMessage is None:
+            self.warning("You don't seem to run the pigment frontend." \
+                         " Can't connect to the player.")
+            return
+
+        bus = common.application.bus
+        bus.register(self._frontend_loaded, PigmentFrontendLoadedMessage)
+
+    def _frontend_loaded(self, msg, sender):
+        frontend = sender
         music_player = \
                 frontend.retrieve_controllers('/poblesec/music_player')[0]
         music_player.player.connect('status-changed',self._music_player_status_cb)
@@ -485,7 +492,7 @@ class DatabaseDBusServiceProvider(ServiceProvider):
         if status != player.PLAYING:
             return defer.succeed(None)
 
-        model = player.playlist[player.current_index]
+        model = player.get_current_model()
         if isinstance(model, MusicTrack):
             current_track_path = model.file_path
         elif isinstance(model, PlayableModel) and \
