@@ -24,10 +24,13 @@ from elisa.core.utils.i18n import install_translation
 
 from elisa.extern.storm_wrapper import wrapper
 
-from storm.locals import Unicode, Int, DateTime, Bool
+from storm.locals import Unicode, Int, Date, DateTime, Bool, \
+     Pickle, And, Not, Select, Float
 
+from elisa.core.utils.i18n import get_current_locale
 from elisa.core.media_uri import MediaUri, quote
 from elisa.core.utils import defer
+from elisa.core import common
 
 from elisa.plugins.base.models.media import PlayableModel
 
@@ -205,9 +208,18 @@ class Image(object):
     # PICTURES_SECTION, MUSIC_SECTION, VIDEO_SECTION
     section = Int()
 
-class Video(object):
+
+class PlayableMixin(object):
+
+    def get_playable_model(self):
+        playable_model = PlayableModel()
+        playable_model.uri = MediaUri("file://%s" % self.file_path)
+        dfr = defer.succeed(playable_model)
+        return dfr
+
+class Video(PlayableMixin):
     """
-    represents an video
+    represents a video
     """
     __storm_table__ = 'videos'
     file_path = Unicode(primary=True)
@@ -218,6 +230,15 @@ class Video(object):
     codec = Unicode()
     thumbnail_uri = Unicode()
 
+    @classmethod
+    def unclassified_videos(cls, *args):
+        store = common.application.store
+        is_movie = Video.file_path.is_in(Select(Movie.file_path, distinct=True))
+        is_tv_episode = Video.file_path.is_in(Select(TVEpisode.file_path,
+                                                     distinct=True))
+        results = store.find(Video, And(Not(is_movie), Not(is_tv_episode), *args))
+        return results
+
 class File(object):
     """
     represente a file
@@ -232,6 +253,71 @@ class File(object):
     last_played = Int()
     hidden = Bool()
 
+
+class Movie(PlayableMixin):
+    __storm_table__ = "movies"
+    file_path = Unicode(primary=True) # refs: Video
+    short_overview = Unicode()
+    title = Unicode()
+    release_date = Date()
+    # URI of a picture file for the movie's cover
+    # eg: http://www.themoviedb.org/image/posters/5389/Batman_forever.jpg
+    cover_uri = Unicode()
+    # URI of a picture file for the movie's backdrop
+    # eg: http://www.themoviedb.org/image/backdrops/5389/Batman_forever.jpg
+    backdrop_uri = Unicode()
+    metadata_lang_code = Unicode()
+    runtime = Int() # in minutes
+    crew = Pickle()
+    production_countries = Pickle()
+    user_rating = Float()
+    budget = Int()
+    revenue = Int()
+    imdb_id = Unicode()
+
+class TVShow(object):
+    __storm_table__ = "tvshows"
+    id = Int(primary=True)
+    thetvdb_id = Int()
+    name = Unicode()
+    filesystem_name = Unicode()
+    metadata_lang_code = Unicode()
+    poster_uri = Unicode()
+    season_posters = Pickle()
+
+class TVSeason(object):
+    __storm_table__ = "tvseasons"
+    id = Int(primary=True)
+    number = Int()
+    tvshow_id = Int() # refs: TVShow
+
+    def poster_uri(self):
+        def got_show(show):
+            poster_uri = None
+            if show.season_posters and self.number in show.season_posters:
+                lang_code = unicode(get_current_locale().split('_')[0])
+                posters_by_lang = show.season_posters[self.number]
+                if lang_code not in posters_by_lang:
+                    lang_code = u'en'
+                if lang_code in posters_by_lang:
+                    posters = posters_by_lang[lang_code]
+                    poster_uri = posters[0]
+            return poster_uri
+
+        dfr = self.tvshow
+        dfr.addCallback(got_show)
+        return dfr
+
+class TVEpisode(PlayableMixin):
+    __storm_table__ = "tvepisodes"
+    file_path = Unicode(primary=True) # refs: Video
+    number = Int()
+    season_id = Int() #refs: TVSeason
+    name = Unicode()
+    guest_stars = Unicode()
+    overview = Unicode()
+    poster_uri = Unicode()
+
 class Tag(object):
     """
     representation of a TAG
@@ -272,6 +358,7 @@ PhotoAlbum.photos = wrapper.DeferredReferenceSet(PhotoAlbum.name, Image.album_na
 MusicTrack.file = wrapper.DeferredReference(MusicTrack.file_path, File.path)
 Image.file = wrapper.DeferredReference(Image.file_path, File.path)
 Video.file = wrapper.DeferredReference(Video.file_path, File.path)
+Movie.file = wrapper.DeferredReference(Movie.file_path, File.path)
 
 # link file to more specific types
 File.music_track = wrapper.DeferredReference(File.path, MusicTrack.file_path)
@@ -281,3 +368,9 @@ File.tags = wrapper.DeferredReferenceSet(File.path, FileTags.file_path,
 
 Tag.files = wrapper.DeferredReferenceSet(Tag.name, FileTags.tag_name,
         FileTags.file_path, File.path)
+
+# links for tvshows/seasons/episodes
+TVSeason.tvshow = wrapper.DeferredReference(TVSeason.tvshow_id, TVShow.id)
+TVEpisode.season = wrapper.DeferredReference(TVEpisode.season_id, TVSeason.id)
+TVShow.seasons = wrapper.DeferredReferenceSet(TVShow.id, TVSeason.tvshow_id)
+TVSeason.episodes = wrapper.DeferredReferenceSet(TVSeason.id, TVEpisode.season_id)
