@@ -73,7 +73,7 @@ def music_search_result_decorator(controller):
     title = _('Local Search Results')
     icon_resource = 'elisa.plugins.poblesec.search'
     searcher_entry = SearcherEntry(searcher, title, icon_resource)
-    controller.searchers.append(searcher_entry)
+    controller.searchers.insert(0, searcher_entry)
     return defer.succeed(None)
 
 
@@ -135,7 +135,7 @@ def music_lib_decades_decorator(controller):
 
 class GenericArtistsController(HierarchyController):
 
-    artist_controller_path = '/poblesec/database/music/albums'
+    artist_controller_path = '/poblesec/database/music/albums_of_artist'
 
     empty_label = _('There are no artists in this section')
     empty_icon = 'elisa.plugins.poblesec.by_artist'
@@ -347,10 +347,65 @@ class GenericAlbumsDbController(HierarchyController):
         return dfr
 
 
+class AlbumsOfArtistDbController(GenericAlbumsDbController):
+
+    def initialize(self, artist=None):
+        deferred = super(AlbumsOfArtistDbController, self).initialize(artist=artist)
+
+        # Add an "All Tracks" album for a given artist
+        all_tracks_album = MusicAlbum()
+        all_tracks_album.name = u'All Tracks'
+        # fake attribute to differentiate the 'All tracks' album from
+        # the regular albums
+        all_tracks_album.all_tracks = True
+        # FIXME: very wrong hot plumbing because we need get_tracks()
+        # to return at some other place.
+        all_tracks_album.get_tracks = lambda: defer.succeed([])
+        all_tracks_album.artist = self.artist # dynamic field
+        self.model.append(all_tracks_album)
+
+        def sort_albums(result_set):
+            result_set.order_by(MusicAlbum.name)
+            return result_set.all()
+
+        def add_albums(albums):
+            self.model.extend(albums)
+            return self
+
+        def get_albums(album_names):
+            store = common.application.store
+            return store.find(MusicAlbum,
+                              MusicAlbum.name.is_in(album_names))
+
+        def order_tracks(result_set):
+            return result_set.values(MusicTrack.album_name)
+
+        def get_tracks(self):
+            return artist.tracks.find(MusicTrack.file_path == File.path,
+                                      File.hidden == False)
+
+        # retrieve tracks for not-database artists
+        if getattr(artist, 'uri', None):
+            self.model.extend(artist.albums)
+        # retrieve tracks for database artists
+        else:
+            deferred.addCallback(get_tracks)
+            deferred.addCallback(order_tracks)
+            deferred.addCallback(get_albums)
+            deferred.addCallback(sort_albums)
+            deferred.addCallback(add_albums)
+
+        return deferred
+
+    def clean(self):
+        dfr = super(AlbumsOfArtistDbController, self).clean()
+        self.albums = None
+        return dfr
+
 class AlbumsDbController(GenericAlbumsDbController):
 
-    def initialize(self, artist=None, albums=None):
-        deferred = super(AlbumsDbController, self).initialize(artist=artist)
+    def initialize(self, albums=None):
+        deferred = super(AlbumsDbController, self).initialize()
 
         self.albums = albums
 
@@ -359,19 +414,6 @@ class AlbumsDbController(GenericAlbumsDbController):
             return result_set.all()
 
         def add_albums(albums):
-            # Add an "All Tracks" album for a given artist
-            if self.artist:
-                all_tracks_album = MusicAlbum()
-                all_tracks_album.name = u'All Tracks'
-                # fake attribute to differentiate the 'All tracks' album from
-                # the regular albums
-                all_tracks_album.all_tracks = True
-                # FIXME: very wrong hot plumbing because we need get_tracks()
-                # to return at some other place.
-                all_tracks_album.get_tracks = lambda: defer.succeed([])
-                all_tracks_album.artist = self.artist # dynamic field
-                self.model.append(all_tracks_album)
-
             self.model.extend(albums)
             return self
 
@@ -379,42 +421,17 @@ class AlbumsDbController(GenericAlbumsDbController):
             self.model.extend(albums)
             return self
 
+        # Show given albums
         if albums is not None:
             return deferred.addCallback(populate_model, albums)
 
-        if artist is None:
-            # Show all albums
-            def get_albums(self):
-                return common.application.store.find(MusicAlbum)
+        # Show all albums
+        def get_albums(self):
+            return common.application.store.find(MusicAlbum)
 
-            deferred.addCallback(get_albums)
-            deferred.addCallback(sort_albums)
-            deferred.addCallback(add_albums)
-
-        else:
-            # Show all albums for a given artist
-            def get_albums(album_names):
-                store = common.application.store
-                return store.find(MusicAlbum,
-                                  MusicAlbum.name.is_in(album_names))
-
-            def order_tracks(result_set):
-                return result_set.values(MusicTrack.album_name)
-
-            def get_tracks(self):
-                return artist.tracks.find(MusicTrack.file_path == File.path,
-                                          File.hidden == False)
-
-            # retrieve tracks for not-database artists
-            if getattr(artist, 'uri', None):
-                self.model.extend(artist.albums)
-            # retrieve tracks for database artists
-            else:
-                deferred.addCallback(get_tracks)
-                deferred.addCallback(order_tracks)
-                deferred.addCallback(get_albums)
-                deferred.addCallback(sort_albums)
-                deferred.addCallback(add_albums)
+        deferred.addCallback(get_albums)
+        deferred.addCallback(sort_albums)
+        deferred.addCallback(add_albums)
 
         return deferred
 
@@ -461,7 +478,7 @@ class AlbumsDbViewMode(AlbumsViewMode):
         return super(AlbumsDbViewMode, self).get_preview_image(item, theme)
 
 
-class AlbumsDbPreviewListController(AlbumsDbController, MenuItemPreviewListController):
+class AlbumsDbPreviewListController(AlbumsDbController, DoubleLineMenuItemPreviewListController):
     view_mode = AlbumsDbViewMode
     fastscroller = True
 
@@ -482,6 +499,27 @@ class AlbumsDbListSwitcherController(ListSwitcherController):
              AlbumsDbGridController]
     default_mode = AlbumsDbPreviewListController
 
+class AlbumsOfArtistDbPreviewListController(AlbumsOfArtistDbController, MenuItemPreviewListController):
+    view_mode = AlbumsDbViewMode
+    fastscroller = True
+
+    def item_to_label(self, item):
+        if isinstance(item, Action):
+            return '#'
+        return item.name
+
+class AlbumsOfArtistDbCoverflowController(AlbumsOfArtistDbController, ImageWithReflectionCoverflowController):
+    view_mode = AlbumsDbViewMode
+
+class AlbumsOfArtistDbGridController(AlbumsOfArtistDbController, GridItemGridController):
+    view_mode = AlbumsDbViewMode
+
+class AlbumsOfArtistDbListSwitcherController(ListSwitcherController):
+    modes = [AlbumsOfArtistDbPreviewListController,
+             AlbumsOfArtistDbCoverflowController,
+             AlbumsOfArtistDbGridController]
+    default_mode = AlbumsOfArtistDbPreviewListController
+
 
 class GenericTracksDbController(HierarchyController):
 
@@ -920,7 +958,7 @@ class GenreDbController(GenericAlbumsDbController):
         return deferred
 
 
-class GenrePreviewListController(GenreDbController, MenuItemPreviewListController):
+class GenrePreviewListController(GenreDbController, DoubleLineMenuItemPreviewListController):
     view_mode = AlbumsDbViewMode
     fastscroller = True
 
@@ -1042,7 +1080,7 @@ class TimeDbController(GenericAlbumsDbController):
         return deferred
 
 
-class TimeDbPreviewListController(TimeDbController, MenuItemPreviewListController):
+class TimeDbPreviewListController(TimeDbController, DoubleLineMenuItemPreviewListController):
     view_mode = AlbumsDbViewMode
 
 class TimeDbCoverflowController(TimeDbController, ImageWithReflectionCoverflowController):
