@@ -341,7 +341,11 @@ class PhotosMonthController(GenericPhotosController):
     def make_actions(self):
         action = ViewSlideshowAction(self)
         action.title = _('Play Slideshow')
-        subtitle = self.date.strftime(_("Slideshow of Photos from %B, %Y"))
+        try:
+            subtitle = self.date.strftime(_("Slideshow of Photos from %B, %Y"))
+        except TypeError:
+            # strftime in python <=2.5 requires a str
+            subtitle = self.date.strftime(_("Slideshow of Photos from %B, %Y").encode("utf-8", "replace"))
         action.subtitle = subtitle
         return [action]
 
@@ -425,7 +429,11 @@ class PhotoTimesViewMode(GenericListViewMode):
         if isinstance(item, Action):
             return defer.succeed(item.title)
 
-        return defer.succeed(item.strftime(_('%B, %Y')))
+        try:
+            return defer.succeed(item.strftime(_('%B, %Y')))
+        except TypeError:
+            # strftime in python <=2.5 requires a str
+            return defer.succeed(item.strftime(_('%B, %Y').encode("utf-8", "replace")))
 
     def get_default_image(self, item):
         if isinstance(item, Action):
@@ -499,9 +507,16 @@ class PhotosTimesController(HierarchyController):
         else:
             controllers = self.frontend.retrieve_controllers('/poblesec/browser')
             history = controllers[0].history
-            dfr = history.append_controller('/poblesec/database/photo/by_month',
-                    model.strftime(_('%B, %Y')), year=model.year, \
-                    month=model.month)
+            try:
+                dfr = history.append_controller('/poblesec/database/photo/by_month',
+                        model.strftime(_('%B, %Y')), year=model.year, \
+                        month=model.month)
+            except TypeError:
+                # strftime in python <=2.5 requires a str
+                dfr = history.append_controller('/poblesec/database/photo/by_month',
+                        model.strftime(_('%B, %Y').encode("utf-8", "replace")), year=model.year, \
+                        month=model.month)
+                
 
 
 
