@@ -58,6 +58,8 @@ class ScanResource(Model):
     @type root_uri:         L{elisa.core.media_uri.MediaUri}
     @ivar name:             a more generic name of this resource
     @type name:             C{unicode}
+    @ivar section:          the section in which the resource was encountered
+    @type section:          C{str}
     @ivar state:            the state it is currently in. See the C{SCANNING*}
                             constants in the class descrition
     @type state:            int
@@ -83,12 +85,12 @@ class ScanResource(Model):
     SCANNING_METADATA = 2
     SCANNING_DONE = 3
 
-    def __init__(self, root_uri=None,name=None):
+    def __init__(self, root_uri=None,name=None, section=None):
         super(ScanResource, self).__init__()
         self.root_uri = root_uri
         self.name = name
+        self.section = section
         self.state = self.SCANNING_NONE
-        self.pending_dfrs = []
 
         self.files_total = 0
         self.files_scanned = 0
