@@ -24,10 +24,10 @@ cmdclass = dict(test=TrialTest, clean=Clean)
 #FIXME: add dependency on storm/twisted-wrapper
 
 setup(name='elisa-plugin-database',
-    version='0.1', 
+    version='0.3', 
     description="Database management support",
     long_description="""Scan the media and store it in the database to make it easier""",
-    license='UNKNOWN', 
+    license='GPLv3', 
     author='Elisa Developers',
     author_email='elisa@lists.fluendo.com',
     keywords='',
@@ -54,6 +54,8 @@ setup(name='elisa-plugin-database',
                           'elisa.plugins.database.music_controller:ArtistsDbListSwitcherController'),
                          ('/poblesec/database/music/albums',
                           'elisa.plugins.database.music_controller:AlbumsDbListSwitcherController'),
+                         ('/poblesec/database/music/albums_of_artist',
+                          'elisa.plugins.database.music_controller:AlbumsOfArtistDbListSwitcherController'),
                          ('/poblesec/database/music/tracks',
                           'elisa.plugins.database.music_controller:TracksDbListSwitcherController'),
                          ('/poblesec/database/music/genres',
@@ -90,12 +92,28 @@ setup(name='elisa-plugin-database',
                           'elisa.plugins.database.playlists_controller:PlayedPhotosListSwitcherController'),
                          ('/poblesec/database/video/list',
                           'elisa.plugins.database.video_controller:AllVideosListSwitcherController'),
+                         ('/poblesec/database/video/unclassified',
+                          'elisa.plugins.database.video_controller:UnclassifiedVideosListSwitcherController'),
+                         ('/poblesec/database/movie/list',
+                          'elisa.plugins.database.video_controller:AllMoviesListSwitcherController'),
+                         ('/poblesec/database/tvshows/list',
+                          'elisa.plugins.database.tvshows_controllers:AllTVSeasonsListSwitcherController'),
+                         ('/poblesec/database/tvseason/list',
+                          'elisa.plugins.database.tvshows_controllers:TVSeasonListSwitcherController'),
                          ('/poblesec/database/video/by_month',
                           'elisa.plugins.database.video_controller:VideosMonthListSwitcherController'),
                          ('/poblesec/database/video/by_date',
                           'elisa.plugins.database.video_controller:VideoTimesListSwitcherController'),
                          ('/poblesec/database/video/track',
                           'elisa.plugins.database.video_controller:VideoTrackListSwitcherController'),
+                         ('/poblesec/database/movie/track',
+                          'elisa.plugins.database.video_controller:MovieTrackListSwitcherController'),
+                         ('/poblesec/database/movie/synopsis',
+                          'elisa.plugins.database.video_controller:MovieSynopsisController'),
+                         ('/poblesec/database/tvepisode/track',
+                          'elisa.plugins.database.tvshows_controllers:TVEpisodeTrackListSwitcherController'),
+                         ('/poblesec/database/tvepisode/synopsis',
+                          'elisa.plugins.database.tvshows_controllers:TVEpisodeSynopsisController'),
                          ('/poblesec/database/.*playlists',
                           'elisa.plugins.poblesec.section:SectionMenuController'),
                          ('/poblesec/database/.*library',
@@ -145,9 +163,11 @@ setup(name='elisa-plugin-database',
                          'elisa.plugins.database.photo_controller:photo_lib_albums_decorator'),
                         # videos library
                         ('/poblesec/database/video_library',
-                         'elisa.plugins.database.video_controller:video_lib_date_decorator'),
+                         'elisa.plugins.database.video_controller:video_lib_unclassified_videos_decorator'),
                         ('/poblesec/database/video_library',
-                         'elisa.plugins.database.video_controller:video_lib_all_videos_decorator'),
+                         'elisa.plugins.database.video_controller:video_lib_all_movies_decorator'),
+                        ('/poblesec/database/video_library',
+                         'elisa.plugins.database.tvshows_controllers:tvshows_lib_decorator'),
                          # videos playlists
                         ('/poblesec/database/video/playlists',
                          'elisa.plugins.database.playlists_controller:recently_added_video_decorator'),
