@@ -100,6 +100,8 @@ class MetadataDummy(object):
             dfr = defer.succeed({})
         self.added.append( (file, dfr) )
         return dfr
+    def clean(self):
+        return defer.succeed(True)
 
 class Dummy(object):pass
 
@@ -136,8 +138,16 @@ class ParserSetupMixin(DBMixin):
 
         for dir in dirs:
             os.removedirs(dir)
+
+        def parser_cleaned(result):
+            return super(ParserSetupMixin, self).tearDown()
         
-        return super(ParserSetupMixin, self).tearDown()
+        if self.parser is None:
+            return parser_cleaned(True)
+
+        dfr = self.parser.clean()
+        dfr.addCallback(parser_cleaned)
+        return dfr
 
     def ensure_file(self, file, dirs=[]):
         directories = None
@@ -651,7 +661,7 @@ class TestMusicParsing(ParserSetupMixin, TestCase):
             def got_track(track):
                 self.assertEquals(track.title, u'testie')
                 self.assertEquals(track.file_path, u'test')
-                self.assertEquals(track.genre, u'rock')
+                self.assertEquals(track.genre, u'cheese')
                 self.assertEquals(track.duration, 1000)
                 self.assertEquals(track.track_number, 10)
                 return track.album.addCallback(got_album).addCallback(
@@ -665,7 +675,7 @@ class TestMusicParsing(ParserSetupMixin, TestCase):
                     'album' : 'music',
                     'song' : 'testie',
                     'duration' : 1000,
-                    "genre" : "rock",
+                    "genre" : "cheese",
                     "date" : 1100818800.0,
                     'track' : 10}
             return self.parser.parse_tags(tags, file)
@@ -894,6 +904,52 @@ class TestMusicParsing(ParserSetupMixin, TestCase):
         dfr = self.store.add(file)
         return dfr.addCallback(parse_it, file).addCallback(check)
 
+    def test_wma_tags(self):
+
+        def check(res):
+
+            def got_album(album):
+                self.assertEquals(album.name, 'music')
+                release_date = datetime.datetime(1982, 1, 1)
+                self.assertEquals(album.release_date, release_date)
+
+            def got_artists(artists):
+                self.assertEquals(artists, ['madonna'])
+
+            def got_track(track):
+                self.assertEquals(track.title, u'testie')
+                self.assertEquals(track.file_path, u'test')
+                self.assertEquals(track.genre, u'cheese')
+                self.assertEquals(track.duration, 1000)
+                self.assertEquals(track.track_number, 10)
+                return track.album.addCallback(got_album).addCallback(
+                        lambda x: track.artists.values(Artist.name)).addCallback(got_artists)
+            
+            return self.store.get(MusicTrack, u'test').addCallback(got_track)
+
+        def parse_it(res, file):
+            tags = {'artist' : None,
+                    'WM/AlbumArtist' : 'madonna',
+                    'file_type' : 'audio',
+                    'album' : None,
+                    'WM/AlbumTitle' : 'music',
+                    'song' : None,
+                    'title' : 'testie',
+                    'duration' : 1000,
+                    "genre" : "cheese",
+                    "date" : None,
+                    'WM/Year' : '1982',
+                    'track' : None,
+                    'WM/TrackNumber' : 10}
+            return self.parser.parse_tags(tags, file)
+
+        file = File()
+        file.path = u"test"
+        dfr = self.store.add(file)
+        return dfr.addCallback(parse_it, file).addCallback(check)
+
+
+
 class TestImageParsing(ParserSetupMixin, TestCase):
 
     def test_with_new_album(self):
