@@ -182,8 +182,12 @@ class TestPhoto(Photo):
 class TestDatabaseDBusServiceProvider(TestDatabaseDBusServiceProviderBase):
     def _start_dbus(self):
         bus = dbus.SessionBus()
-        self.photo = TestPhoto(bus, '/com/fluendo/Elisa/Plugins/Database/Photo')
-        self.music = TestMusic(bus, '/com/fluendo/Elisa/Plugins/Database/Music')
+        self.bus_name = \
+                dbus.service.BusName('com.fluendo.Elisa', bus)
+        self.photo = TestPhoto(bus, '/com/fluendo/Elisa/Plugins/Database/Photo',
+                self.bus_name)
+        self.music = TestMusic(bus, '/com/fluendo/Elisa/Plugins/Database/Music',
+                self.bus_name)
 
 class TestDatabaseDBusServiceProviderNoDBus(TestDatabaseDBusServiceProviderBase):
     """
