@@ -110,6 +110,7 @@ def videos_decorator(controller):
 
     return defer.succeed(None)
 
+
 class FavoritesController(SectionMenuController):
 
     def initialize(self, section=None):
@@ -180,8 +181,7 @@ def focus_refresh_cb(widget, focus, controller):
         if getattr(controller, '_first_initialize', True):
             controller._first_initialize = False
         else:
-            controller.model[:] = []
-            controller.initialize()
+            controller.refresh()
 
 
 class FavoritesAlbumsController(GenericAlbumsDbController):
@@ -193,6 +193,19 @@ class FavoritesAlbumsController(GenericAlbumsDbController):
         self.artist = artist
 
         dfr = super(FavoritesAlbumsController, self).initialize()
+        dfr.addCallback(self.load_data)
+
+        if not getattr(self, '_focus_refresh_cb_handle', None):
+            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
+
+        return dfr
+
+    def refresh(self):
+        self.model[:] = []
+        self.actions[:] = self.actions
+        self.load_data(None)
+
+    def load_data(self, result):
 
         def get_db_albums(result):
             subselect = Select(FavoritesItem.foreign_id,
@@ -255,15 +268,12 @@ class FavoritesAlbumsController(GenericAlbumsDbController):
             self.model.sort(key=key)
             return self
 
-        dfr.addCallback(get_db_albums)
+        dfr = get_db_albums(None)
         dfr.addCallback(got_db_albums)
         dfr.addCallback(get_other_albums)
         dfr.addCallback(got_other_albums_waiting)
         dfr.addCallback(sort_albums)
 
-        if not getattr(self, '_focus_refresh_cb_handle', None):
-            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
-
         return dfr
 
 
@@ -274,6 +284,19 @@ class FavoritesArtistsController(GenericArtistsController):
 
     def initialize(self):
         dfr = super(FavoritesArtistsController, self).initialize()
+        dfr.addCallback(self.load_data)
+        
+        if not getattr(self, '_focus_refresh_cb_handle', None):
+            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
+
+        return dfr
+
+    def refresh(self):
+        self.model[:] = []
+        self.actions[:] = self.actions
+        self.load_data(None)
+
+    def load_data(self, result):
 
         def get_db_artists(result):
             subselect = Select(FavoritesItem.foreign_id,
@@ -338,16 +361,13 @@ class FavoritesArtistsController(GenericArtistsController):
             self.model.sort(key=key)
             return self
 
-        dfr.addCallback(get_db_artists)
+        dfr = get_db_artists(None)
         dfr.addCallback(sort_db_artists)
         dfr.addCallback(got_db_artists)
         dfr.addCallback(get_other_artists)
         dfr.addCallback(got_other_artists_waiting)
         dfr.addCallback(sort_artists)
 
-        if not getattr(self, '_focus_refresh_cb_handle', None):
-            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
-
         return dfr
 
 
@@ -362,7 +382,19 @@ class FavoritesTracksController(GenericTracksDbController):
         self.tracks = tracks
 
         dfr = super(FavoritesTracksController, self).initialize()
+        dfr.addCallback(self.load_data)
+        
+        if not getattr(self, '_focus_refresh_cb_handle', None):
+            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
 
+        return dfr
+
+    def refresh(self):
+        self.model[:] = []
+        self.actions[:] = self.actions
+        self.load_data(None)
+
+    def load_data(self, result):
         def get_db_tracks(result):
             subselect = Select(FavoritesItem.foreign_id,
                                FavoritesItem.foreign_class == u'MusicTrack')
@@ -430,17 +462,15 @@ class FavoritesTracksController(GenericTracksDbController):
             return self
 
         if self.track is None:
-            dfr.addCallback(get_db_tracks)
+            dfr = get_db_tracks(None)
             dfr.addCallback(sort_db_tracks_title)
             dfr.addCallback(got_db_tracks)
             dfr.addCallback(get_other_tracks)
             dfr.addCallback(got_other_tracks_waiting)
             dfr.addCallback(sort_tracks)
 
-        if not getattr(self, '_focus_refresh_cb_handle', None):
-            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
+            return dfr
 
-        return dfr
 
 class FavoritesRadiosController(GenericShoutcastController):
 
@@ -449,8 +479,22 @@ class FavoritesRadiosController(GenericShoutcastController):
 
     def initialize(self, uri=None, station=None):
         dfr = super(FavoritesRadiosController, self).initialize(uri=uri, station=station)
+        self.station = station
 
-        if station is None:
+        if not getattr(self, '_focus_refresh_cb_handle', None):
+            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
+
+        dfr.addCallback(self.load_data)
+        return dfr
+
+    def refresh(self):
+        self.model[:] = []
+        self.actions[:] = self.actions
+        self.load_data(None)
+
+    def load_data(self, result):
+
+        if self.station is None:
             def get_radios(result):
                 dfr = application.store.find(FavoritesItem,
                                              FavoritesItem.foreign_class == u'InternetRadio')
@@ -471,17 +515,14 @@ class FavoritesRadiosController(GenericShoutcastController):
                 result_set.order_by(FavoritesItem.title)
                 return result_set.all()
 
-            dfr.addCallback(get_radios)
+            dfr = get_radios(None)
             dfr.addCallback(sort_radios)
             dfr.addCallback(got_radios)
 
-        if not getattr(self, '_focus_refresh_cb_handle', None):
-            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
-
-        return dfr
+            return dfr
 
 
-class FavoritesAlbumsVerticalWithPreview(FavoritesAlbumsController, MenuItemPreviewListController):
+class FavoritesAlbumsVerticalWithPreview(FavoritesAlbumsController, DoubleLineMenuItemPreviewListController):
     view_mode = AlbumsDbViewMode
     fastscroller = True
 
@@ -490,12 +531,15 @@ class FavoritesAlbumsVerticalWithPreview(FavoritesAlbumsController, MenuItemPrev
             return '#'
         return item.name
 
+
 class FavoritesAlbumsCoverflow(FavoritesAlbumsController, ImageWithReflectionCoverflowController):
     view_mode = AlbumsDbViewMode
 
+
 class FavoritesAlbumsGrid(FavoritesAlbumsController, GridItemGridController):
     view_mode = AlbumsDbViewMode
 
+
 class FavoritesAlbumsListSwitcher(ListSwitcherController):
     modes = [FavoritesAlbumsVerticalWithPreview, FavoritesAlbumsCoverflow, FavoritesAlbumsGrid]
     default_mode = FavoritesAlbumsVerticalWithPreview
@@ -510,6 +554,7 @@ class FavoritesArtistsVerticalWithPreview(FavoritesArtistsController, MenuItemPr
             return '#'
         return item.name
 
+
 class FavoritesArtistsCoverflow(FavoritesArtistsController, ImageWithReflectionCoverflowController):
     view_mode = ArtistsDbViewMode
     fastscroller = True
@@ -519,15 +564,17 @@ class FavoritesArtistsCoverflow(FavoritesArtistsController, ImageWithReflectionC
             return '#'
         return item.name
 
+
 class FavoritesArtistsGrid(FavoritesArtistsController, GridItemGridController):
     view_mode = ArtistsDbViewMode
 
+
 class FavoritesArtistsListSwitcher(ListSwitcherController):
     modes = [FavoritesArtistsVerticalWithPreview, FavoritesArtistsCoverflow, FavoritesArtistsGrid]
     default_mode = FavoritesArtistsVerticalWithPreview
 
 
-class FavoritesTracksVerticalWithPreview(FavoritesTracksController, MenuItemPreviewListController):
+class FavoritesTracksVerticalWithPreview(FavoritesTracksController, DoubleLineMenuItemPreviewListController):
     view_mode = DBTracksViewMode
     fastscroller = True
 
@@ -539,9 +586,11 @@ class FavoritesTracksVerticalWithPreview(FavoritesTracksController, MenuItemPrev
 class FavoritesTracksCoverflow(FavoritesTracksController, ImageWithReflectionCoverflowController):
     view_mode = DBTracksViewMode
 
+
 class FavoritesTracksGrid(FavoritesTracksController, GridItemGridController):
     view_mode = DBTracksViewMode
 
+
 class FavoritesTracksListSwitcher(ListSwitcherController):
     modes = [FavoritesTracksVerticalWithPreview, FavoritesTracksCoverflow, FavoritesTracksGrid]
     default_mode = FavoritesTracksVerticalWithPreview
@@ -553,9 +602,11 @@ class FavoritesRadiosVerticalWithPreview(FavoritesRadiosController, MenuItemPrev
 class FavoritesRadiosCoverflow(FavoritesRadiosController, ImageWithReflectionCoverflowController):
     view_mode = ShoutcastViewMode
 
+
 class FavoritesRadiosGrid(FavoritesRadiosController, GridItemGridController):
     view_mode = ShoutcastViewMode
 
+
 class FavoritesRadiosListSwitcher(ListSwitcherController):
     modes = [FavoritesRadiosVerticalWithPreview, FavoritesRadiosCoverflow, FavoritesRadiosGrid]
     default_mode = FavoritesRadiosVerticalWithPreview
@@ -568,6 +619,19 @@ class FavoritesPhotosController(GenericPhotosController):
 
     def initialize(self, album=None, photo=None, photos=None):
         dfr = super(FavoritesPhotosController, self).initialize(album=album, photo=photo, photos=photos)
+        dfr.addCallback(self.load_data, album, photo, photos)
+
+        if not getattr(self, '_focus_refresh_cb_handle', None):
+            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
+
+        return dfr
+
+    def refresh(self):
+        self.model[:] = []
+        self.actions[:] = self.actions
+        self.load_data(None)
+
+    def load_data(self, result, album=None, photo=None, photos=None):
 
         def get_photos(result):
             subselect = Select(FavoritesItem.foreign_id,
@@ -585,14 +649,10 @@ class FavoritesPhotosController(GenericPhotosController):
             return result_set.all()
 
         if photo is None:
-            dfr.addCallback(get_photos)
+            dfr = get_photos(None)
             dfr.addCallback(sort_photos)
             dfr.addCallback(got_photos)
-
-        if not getattr(self, '_focus_refresh_cb_handle', None):
-            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
-
-        return dfr
+            return dfr
 
 
 class FavoritesPhotoAlbumsController(GenericPhotoAlbumsController):
@@ -602,6 +662,19 @@ class FavoritesPhotoAlbumsController(GenericPhotoAlbumsController):
 
     def initialize(self):
         dfr = super(FavoritesPhotoAlbumsController, self).initialize()
+        dfr.addCallback(self.load_data)
+
+        if not getattr(self, '_focus_refresh_cb_handle', None):
+            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
+
+        return dfr
+
+    def refresh(self):
+        self.model[:] = []
+        self.actions[:] = self.actions
+        self.load_data(None)
+
+    def load_data(self, result):
 
         def get_albums(result):
             subselect = Select(FavoritesItem.foreign_id,
@@ -616,25 +689,24 @@ class FavoritesPhotoAlbumsController(GenericPhotoAlbumsController):
             result_set.order_by(PhotoAlbum.name)
             return result_set.all()
 
-        dfr.addCallback(get_albums)
+        dfr = get_albums(None)
         dfr.addCallback(sort_albums_title)
         dfr.addCallback(got_albums)
-
-        if not getattr(self, '_focus_refresh_cb_handle', None):
-            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
-
         return dfr
 
 
 class FavoritesPhotosVerticalWithPreview(FavoritesPhotosController, MenuItemPreviewListController):
     view_mode = PhotoViewMode
 
+
 class FavoritesPhotosCoverflow(FavoritesPhotosController, ImageWithReflectionCoverflowController):
     view_mode = PhotoViewMode
 
+
 class FavoritesPhotosGrid(FavoritesPhotosController, GridItemGridController):
     view_mode = PhotoViewMode
 
+
 class FavoritesPhotosListSwitcher(ListSwitcherController):
     modes = [FavoritesPhotosVerticalWithPreview, FavoritesPhotosCoverflow, FavoritesPhotosGrid]
     default_mode = FavoritesPhotosVerticalWithPreview
@@ -643,12 +715,15 @@ class FavoritesPhotosListSwitcher(ListSwitcherController):
 class FavoritesPhotoAlbumsVerticalWithPreview(FavoritesPhotoAlbumsController, MenuItemPreviewListController):
     view_mode = PhotoAlbumViewMode
 
+
 class FavoritesPhotoAlbumsCoverflow(FavoritesPhotoAlbumsController, ImageWithReflectionCoverflowController):
     view_mode = PhotoAlbumViewMode
 
+
 class FavoritesPhotoAlbumsGrid(FavoritesPhotoAlbumsController, GridItemGridController):
     view_mode = PhotoAlbumViewMode
 
+
 class FavoritesPhotoAlbumsListSwitcher(ListSwitcherController):
     modes = [FavoritesPhotoAlbumsVerticalWithPreview, FavoritesPhotoAlbumsCoverflow, FavoritesPhotoAlbumsGrid]
     default_mode = FavoritesPhotoAlbumsVerticalWithPreview
@@ -661,7 +736,19 @@ class FavoritesVideosController(VideoController):
 
     def initialize(self):
         dfr = super(FavoritesVideosController, self).initialize()
-        
+        dfr.addCallback(self.load_data)
+
+        if not getattr(self, '_focus_refresh_cb_handle', None):
+            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
+
+        return dfr
+
+    def refresh(self):
+        self.model[:] = []
+        self.actions[:] = self.actions
+        self.load_data(None)
+
+    def load_data(self, result):
         def get_videos(result):
             subselect = Select(FavoritesItem.foreign_id,
                                FavoritesItem.foreign_class == u'Video')
@@ -677,24 +764,25 @@ class FavoritesVideosController(VideoController):
             result_set.order_by(Video.name)
             return result_set.all()
 
-        dfr.addCallback(get_videos)
+        dfr = get_videos(None)
         dfr.addCallback(sort_videos_title)
         dfr.addCallback(got_videos)
 
-        if not getattr(self, '_focus_refresh_cb_handle', None):
-            self._focus_refresh_cb_handle = self.widget.connect('focus', focus_refresh_cb, self)
-
         return dfr
-    
+
+
 class FavoritesVideosVerticalWithPreview(FavoritesVideosController, MenuItemPreviewListController):
     view_mode = VideoViewMode
 
+
 class FavoritesVideosCoverflow(FavoritesVideosController, ImageWithReflectionCoverflowController):
     view_mode = VideoViewMode
 
+
 class FavoritesVideosGrid(FavoritesVideosController, GridItemGridController):
     view_mode = VideoViewMode
 
+
 class FavoritesVideosListSwitcher(ListSwitcherController):
     modes = [FavoritesVideosVerticalWithPreview, FavoritesVideosCoverflow, FavoritesVideosGrid]
     default_mode = FavoritesVideosVerticalWithPreview
