@@ -49,7 +49,7 @@ class FavoritesItem(object):
 
 if __name__ == '__main__':
     """Quick testing"""
-    from elisa.core.application import CONFIG_DIR
+    from elisa.core.default_config import CONFIG_DIR
     from elisa.plugins.database.models import *
     from elisa.plugins.database.media_scanner import SCHEMA
     from storm.locals import *
