@@ -32,7 +32,8 @@ from elisa.plugins.gstreamer.thumbnail import PngImageSnapshotBin, \
 
 from elisa.plugins.gstreamer import thumbnail
  
-supported_metadata_keys = set(['artist', 'album', 'song', 'track', \
+supported_metadata_keys = set(['artist', 'album', 'song', 'track', 
+        'WM/AlbumTitle', 'WM/AlbumArtist', 'WM/TrackNumber', 'WM/Year',
         'thumbnail','date', 'date-time-modified'])
 media_type_keys = set(['uri', 'file_type', 'mime_type'])
 thumbnail_keys = set(['uri', 'thumbnail'])
