@@ -23,6 +23,7 @@ from twisted.web2 import responsecode
 
 from elisa.core.utils.cancellable_defer import CancellableDeferred, \
                                                CancelledError
+from elisa.core.media_uri import MediaUri
 
 from elisa.plugins.http_client.extern.client_http \
     import HTTPClientProtocol, ClientRequest
@@ -479,6 +480,21 @@ class ElisaAdvancedHttpClient(ElisaHttpClient):
     def __init__(self, host, port=80):
         super(ElisaAdvancedHttpClient, self).__init__(host, port,
                                                       pipeline=True)
+        self._redirection_client = None
+
+    def _create_redirection_client(self, result_or_failure, host, port):
+        self._redirection_client = \
+            ElisaAdvancedHttpClient(host, port)
+
+    def close(self):
+        try:
+            dfr = self._redirection_client.close()
+        except AttributeError:
+            return super(ElisaAdvancedHttpClient, self).close()
+        else:
+            dfr.addBoth(lambda result_or_failure: \
+                        super(ElisaAdvancedHttpClient, self).close())
+            return dfr
 
     def _request_done(self, response, request):
         """
@@ -486,20 +502,55 @@ class ElisaAdvancedHttpClient(ElisaHttpClient):
         """
         if response.code in REDIRECTION_CODES:
             # HTTP redirection
-            # FIXME: handle redirect loops
+            # FIXME: handle redirection loops
             location = response.headers.getHeader('location')
-            redirection = ClientRequest(request.method, location, {}, None)
-            # copy the old headers
-            redirection.headers = request.headers
+            if not location.startswith('http'):
+                # No host provided, assuming the same host and port
+                same_host = True
+                location = 'http://%s:%d%s' % (self._host, self._port, location)
+            else:
+                location_uri = MediaUri(location)
+                same_host = (location_uri.host == self._host)
 
-            if not redirection.headers.getHeader('host'):
-                redirection.headers.setHeader('host', self._host)
-            redirection.defer = defer.Deferred()
-            self._queued_requests.insert(0, redirection)
             assert request == self._written_requests.pop(0)
             self._connector.factory.retries = 0
-            self._submit_redirection_request(redirection)
-            return redirection.defer
+
+            redirection = ClientRequest(request.method, location, {}, None)
+            redirection.headers = request.headers
+
+            if same_host:
+                if redirection.headers.getHeader('host') is None:
+                    redirection.headers.setHeader('host', self._host)
+
+                redirection.defer = defer.Deferred()
+                self._queued_requests.insert(0, redirection)
+
+                self._submit_redirection_request(redirection)
+                return redirection.defer
+            else:
+                def do_redirection_request(result_or_failure=None):
+                    redirection.headers.setHeader('host', str(location_uri.host))
+                    redirection_dfr = \
+                        self._redirection_client.request_full(redirection)
+                    return redirection_dfr
+
+                if self._redirection_client is not None:
+                    if self._redirection_client._host != str(location_uri.host) or \
+                        self._redirection_client._port != location_uri.port:
+                        close_dfr = self._redirection_client.close()
+                        close_dfr.addBoth(self._create_redirection_client,
+                                          str(location_uri.host),
+                                          location_uri.port or 80)
+                        close_dfr.addCallback(do_redirection_request)
+                        return close_dfr
+                    else:
+                        # Reuse the same redirection HTTP client
+                        return do_redirection_request()
+                else:
+                    self._create_redirection_client(None,
+                                                    str(location_uri.host),
+                                                    location_uri.port or 80)
+                    return do_redirection_request()
         else:
             # Normal response
             assert request == self._written_requests.pop(0)
