@@ -16,6 +16,7 @@
 # Authors: Alessandro Decina <alessandro@fluendo.com>
 
 import dbus
+import dbus.service
 
 class DBusFrontend(dbus.service.Object):
     interface = 'com.fluendo.Elisa.Plugins.Pigment.Frontend'
@@ -29,6 +30,9 @@ class DBusFrontend(dbus.service.Object):
     def show(self):
         toplevel = self._get_toplevel_window()
         toplevel.show()
+        toplevel.focus()
+
+        self._show_player_osd()
 
     @dbus.service.method(dbus_interface=interface,
             in_signature='', out_signature='') 
@@ -38,3 +42,14 @@ class DBusFrontend(dbus.service.Object):
 
     def _get_toplevel_window(self):
         return self.frontend.gtk_window or self.frontend.viewport
+
+    def _show_player_osd(self):
+        path = "/poblesec"
+        main = self.frontend.retrieve_controllers(path)[0]
+        player = main.current_player
+
+        if main.focused_controller == player:
+            # the player is in foreground, show the osd
+            player.player_osd.show()
+            player.player_osd.control_ribbon.show()
+            player.player_osd.mouse_osd.show()
