@@ -75,6 +75,9 @@ class PigmentController(Controller, gobject.GObject):
         self.path = path
 
     def handle_input(self, input_manager, input_event):
+        if input_event.value == EventValue.KEY_EXIT:
+            common.application.stop()
+            return True
         return False
 
     def has_focus(self):
