@@ -17,11 +17,12 @@
 __maintainer__ = "Benjamin Kampmann <benjamin@fluendo.com>"
 
 from elisa.core import common
-from elisa.core.utils.dist import read_mappings
+from elisa.core.utils.misc import read_mappings
 from elisa.core.components.frontend import Frontend
 from elisa.core.pattern_matcher import UriPatternMatcher, MatchNotFound
-from elisa.core.plugin_registry import PluginStatusMessage, PluginNotFound
 from elisa.core.log import Loggable
+from elisa.core.utils import typefinding
+from elisa.core.media_uri import MediaUri, unquote
 
 from elisa.extern.log.log import getFailureMessage
 
@@ -33,6 +34,9 @@ from twisted.python.failure import Failure
 from twisted.python import reflect
 from twisted.internet import reactor, task, defer
 
+from elisa.core.application import ComponentsLoadedMessage
+from elisa.plugins.pigment.message import PigmentFrontendLoadedMessage
+
 import pgm
 from pgm.timing.controller import Controller
 from pgm.timing.ticker import Ticker
@@ -48,24 +52,33 @@ try:
 except ImportError:
     pass
 
+
 class ControllerNotFound(Exception):
     pass
 
+
 class PigmentFrontendExtensionMixin(Loggable):
 
     def __init__(self):
         super(PigmentFrontendExtensionMixin, self).__init__()
         self.controller_matcher = UriPatternMatcher()
         self.decorator_matcher = UriPatternMatcher()
-
-        self._load_controller_mappings()
-        self._load_decorator_mappings()
-
-        bus = common.application.bus
-        bus.register(self._plugin_status_changed_cb, PluginStatusMessage)
-
         self._controller_store = {}
 
+    def _load_enabled_controller_and_decorator_mappings(self):
+        """
+        Load the controller and decorator mappings from all the enabled
+        plugins' metadata.
+        """
+        registry = common.application.plugin_registry
+        enabled_plugins = [plugin for plugin in registry.get_enabled_plugins()]
+        for dist in pkg_resources.working_set:
+            if dist.key not in enabled_plugins:
+                continue
+            self._update_controller_mappings(dist, True)
+            self._update_decorator_mappings(dist, True)
+            self._loaded_plugins.append(dist.key)
+
     def _update_controller_mappings(self, plugin, enabled):
         # Load/unload the controller mappings for a given plugin.
         metadata = 'controller_mappings.txt'
@@ -79,17 +92,6 @@ class PigmentFrontendExtensionMixin(Loggable):
             else:
                 self.remove_controller(path_pattern)
 
-    def _load_controller_mappings(self):
-        """
-        Load the controller mappings from all the enabled plugins' metadata.
-        """
-        registry = common.application.plugin_registry
-        enabled_plugins = [plugin for plugin in registry.get_enabled_plugins()]
-        for dist in pkg_resources.working_set:
-            if dist.key not in enabled_plugins:
-                continue
-            self._update_controller_mappings(dist, True)
-
     def _update_decorator_mappings(self, plugin, enabled):
         # Load/unload the decorator mappings for a given plugin.
         metadata = 'decorator_mappings.txt'
@@ -103,29 +105,15 @@ class PigmentFrontendExtensionMixin(Loggable):
             else:
                 self.remove_decorator(path_pattern)
 
-    def _load_decorator_mappings(self):
+    def plugin_status_changed_cb(self, plugin, status):
         """
-        Load the decorator mappings from all the enabled plugins' metadata.
+        Callback meant to be invoked (by the plugin registry) when the status
+        of a plugin has changed.
+        Update the controller and decorator mappings accordingly.
         """
-        registry = common.application.plugin_registry
-        enabled_plugins = [plugin for plugin in registry.get_enabled_plugins()]
-        for dist in pkg_resources.working_set:
-            if dist.key not in enabled_plugins:
-                continue
-            self._update_decorator_mappings(dist, True)
-
-    def _plugin_status_changed_cb(self, message, sender):
-        # Notification that the status of a plugin has changed.
-        # Update the controller and decorator mappings accordingly.
-        try:
-            requirement = pkg_resources.Requirement.parse(message.plugin_name)
-            plugin = pkg_resources.working_set.find(requirement)
-        except KeyError:
-            raise PluginNotFound(message.plugin_name)
-
-        enabled = (message.action == PluginStatusMessage.ActionType.ENABLED)
-        self._update_controller_mappings(plugin, enabled)
-        self._update_decorator_mappings(plugin, enabled)
+        self._update_controller_mappings(plugin, status)
+        self._update_decorator_mappings(plugin, status)
+        return defer.succeed(None)
 
     def add_controller(self, path_pattern, controller):
         """
@@ -300,6 +288,7 @@ class PigmentFrontendExtensionMixin(Loggable):
 
         return defer.succeed(controller)
 
+
 class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
     """
     Specialised L{elisa.core.components.frontend.Frontend} for the Pigment
@@ -350,6 +339,7 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
 
     def initialize(self):
         self._master_drawables = {}
+        self._theme = None
 
         dfr = super(PigmentFrontend, self).initialize()
 
@@ -372,11 +362,7 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
         # all the CPU by rendering as fast as possible; it happens when
         # synchronisation with Vblank fails completely
         # See Elisa bug: https://bugs.launchpad.net/elisa/+bug/231899
-        os.environ["PGM_GL_FPS"] = "60"
-
-        # deactivate synchronisation to VBlank; avoids flickering on HP mini
-        # 1100
-        os.environ["PGM_GL_VBLANK"] = "0"
+        os.environ["PGM_GL_FPS"] = "120"
 
         # signal handlers id
         self._signal_handler_ids = []
@@ -385,25 +371,29 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
         # some reason pgm is not defined. This should be fixed with Python
         # 3000
         import pgm
-        import gtk
 
         factory = pgm.ViewportFactory('opengl')
         viewport = factory.create()
 
         self.viewport = viewport
 
-        viewport.title = 'HP MediaStyle Powered by Elisa'
-
-	try:
-            pix = gtk.icon_theme_get_default ().load_icon ("elisa", 48, 0)
-            viewport.set_icon (pix)
-        except:
-            pass
-
+        viewport.title = 'Elisa Media Center'
         self.canvas = pgm.Canvas()
 
         viewport.set_canvas(self.canvas)
-        viewport.connect('delete-event', self._viewport_delete_event)
+        id = viewport.connect('delete-event', self._viewport_delete_event)
+        self._signal_handler_ids.append(id)
+        id = viewport.connect('drag-motion-event',
+                              self._viewport_drag_motion_event)
+        self._signal_handler_ids.append(id)
+        id = viewport.connect('drag-drop-event', self._viewport_drag_drop_event)
+        self._signal_handler_ids.append(id)
+        id = viewport.connect('drag-leave-event',
+                              self._viewport_drag_leave_event)
+        self._signal_handler_ids.append(id)
+
+        self._in_drag = False
+        self._drag_motion_result = False
         
         if platform.system() == 'Windows':
             from elisa.plugins.pigment.messages import ViewportWindowCreated
@@ -444,6 +434,7 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
         if self.config.as_bool('use_gtk') is True:
             self.debug("using gtk")
 
+            import gtk
             import pgm.gtk
 
             self.gtk_window = gtk.Window(gtk.WINDOW_TOPLEVEL)
@@ -502,31 +493,52 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
                                   self._motion_notify_callback)
             self._signal_handler_ids.append(id)
 
+        self.pigment_input = PigmentInput()
+        self.pigment_input.viewport = self.viewport
+
+        application = common.application
+        application.input_manager.register_component(self.pigment_input)
+        application.input_manager.connect('input-event', self.handle_input)
+
+        application.bus.register(self._components_loaded_msg,
+                                                    ComponentsLoadedMessage)
+
+        self._initialize_dbus()
+
+        return dfr
+
+
+    def _components_loaded_msg(self, message, sender):
+
+        # load the mappings and register a callback for updates
+
+        self._loaded_plugins = []
+        self._load_enabled_controller_and_decorator_mappings()
+
+        plugin_registry = common.application.plugin_registry
+        plugin_registry.register_plugin_status_changed_callback(self.plugin_status_changed_cb)
+
+        # load the first controller in the next iteration
+        reactor.callLater(0, self._load_first_controller)
+
+    def _load_first_controller(self):
+        # Create the first PigmentController
+        controller_path = self.config['controller_path']
+        dfr = self.create_controller(controller_path)
+
         def controller_created(controller):
             # remember the root controller
             self.controller = controller
             controller.widget.canvas = self.canvas
             controller.widget.size = self.canvas.size
+            # sent out the loaded message
+            message = PigmentFrontendLoadedMessage(controller)
+            common.application.bus.send_message(message, sender=self)
             return self
 
-        def frontend_initialized(frontend):
-            # create the first PigmentController
-            controller_path = self.config['controller_path']
-            dfr_controller = self.create_controller(controller_path)
-            dfr_controller.addCallback(controller_created)
-            return dfr_controller
-
-        dfr.addCallback(frontend_initialized)
-
-        self.pigment_input = PigmentInput()
-        self.pigment_input.viewport = self.viewport
-        common.application.input_manager.register_component(self.pigment_input)
-        common.application.input_manager.connect('input-event', self.handle_input)
-
-        self._initialize_dbus()
-
+        dfr.addCallback(controller_created)
         return dfr
-    
+
     def _viewport_delete_event(self, viewport, event):
         common.application.stop()
 
@@ -540,6 +552,7 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
 
     def _initialize_theme(self):
         """Initialize a theme for the frontend."""
+
         theme_modulename = self.config.get('theme')
 
         if not theme_modulename:
@@ -547,11 +560,19 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
         else:
             self.debug("Setting theme '%s'" % self.config.get('theme'))
             theme = Theme.load_from_module(theme_modulename)
+            self._style_handler_id = theme.connect('styles-updated',
+                                                   self._reload_theme)
+            self._resource_handler_id = theme.connect('resources-updated',
+                                                      self._reload_theme)
             # setting the theme for the widgets, too
             Theme.set_default(theme)
 
         self.set_theme(Theme.get_default())
 
+    def _reload_theme(self, theme):
+        self.info('reloading theme')
+        self.set_theme(self._theme)
+
     def set_theme(self, theme):
         """Set a new theme for the frontend.
 
@@ -571,24 +592,7 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
             return
 
         for widget in self.controller.widget.get_descendants():
-            widget_module = ".".join(widget.__class__.__module__.split('.')[0:-1])
-            widget_class = widget.__class__.__name__
-            widget_path = widget_module + '.' + widget_class
-
-            self.debug("Setting style for widget at path '%s'" % widget_path)
-
-            for state in [const.STATE_NORMAL,
-                          const.STATE_ACTIVE,
-                          const.STATE_PRELIGHT,
-                          const.STATE_SELECTED,
-                          const.STATE_INSENSITIVE]:
-                style = theme.get_style_for_widget(widget_path, state)
-                if style:
-                    try:
-                        widget._styles[state].update(style)
-                    except KeyError:
-                        pass
-            widget.style = widget._styles[widget.state]
+            widget._init_styles()
 
     def get_theme(self):
         """Get the current theme.
@@ -606,14 +610,32 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
         @type path: str
         @param image: drawable into which the icon will be loaded
         @type image: L{pgm.Image}
+
+        @rtype: L{twisted.internet.defer.Deferred}
+        @return: triggered whenever the image is loaded and shown
         """
-        # FIXME: unused masters are never released
+        def unclone(result, master, path): 
+            # remove master when there are no clones left
+            master.connect('un-cloned', self._clone_removed, path)
+            return result
+
         if not self._master_drawables.has_key(path):
             # create a master drawable
             master = pgm.Image()
             master.visible = False
             image_path = self.get_theme().get_resource(path)
-            master.set_from_file(image_path)
+
+            master.defer = defer.Deferred()
+
+            # as soon as the file is loaded, connect to the un-cloned signal
+            # so that we can clean up the master if it is not needed anylonger
+            master.defer.addCallback(unclone, master, path)
+
+            signal_id = master.connect('file-loaded',
+                                    self._file_loaded, image_path)
+            master.file_loaded_signal_id = signal_id
+
+            master.set_from_file(image_path) 
             self.canvas.add(pgm.DRAWABLE_FAR, master)
 
             self._master_drawables[path] = master
@@ -622,6 +644,21 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
             master = self._master_drawables[path]
 
         image.set_from_image(master)
+        return master.defer
+
+    def _file_loaded(self, widget, file_path):
+        widget.disconnect(widget.file_loaded_signal_id)
+        del widget.file_loaded_signal_id
+
+        widget.defer.callback(file_path)
+
+    def _clone_removed(self, image, number, path):
+        if number == 0:
+            try:
+                image = self._master_drawables.pop(path)
+                self.canvas.remove(image)
+            except KeyError:
+                pass
 
     def clean(self):
         self._clean_dbus()
@@ -635,6 +672,10 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
         for id in self._signal_handler_ids:
             viewport.disconnect(id)
 
+        # disconnecting from the theme signals
+        self._theme.disconnect(self._style_handler_id)
+        self._theme.disconnect(self._resource_handler_id)
+
         # unbinding the canvas from the OpenGL viewport
         viewport.set_canvas(None)
 
@@ -678,8 +719,10 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
             return
 
         bus = dbus.SessionBus()
+        self.bus_name = \
+                dbus.service.BusName('com.fluendo.Elisa', bus)
         self.dbus_frontend = DBusFrontend(self, bus, 
-                '/com/fluendo/Elisa/Plugins/Pigment/Frontend')
+                '/com/fluendo/Elisa/Plugins/Pigment/Frontend', self.bus_name)
 
     def _clean_dbus(self):
         if 'dbus' not in sys.modules:
@@ -689,6 +732,44 @@ class PigmentFrontend(Frontend, PigmentFrontendExtensionMixin):
         bus = dbus.SessionBus()
         self.dbus_frontend.remove_from_connection(bus,
                 '/com/fluendo/Elisa/Plugins/Pigment/Frontend')
+        # BusName implements __del__, eew
+        del self.bus_name
 
         # remove the reference cycle
         del self.dbus_frontend
+        
+    def _viewport_drag_motion_event(self, viewport, event):
+        if not self._in_drag:
+            self._in_drag = True
+            
+            # We only check the first uri since PoblesecController.playfiles()
+            # will only check that anyway.
+            file_uri = MediaUri(event.uri[0])
+            # We only handle file for now because
+            # PoblesecController.playfiles() only knows about files.
+            if file_uri.scheme != 'file':
+                self._drag_motion_result = False
+            else:
+                try:
+                    media_type = typefinding.typefind(file_uri)
+                    self._drag_motion_result = True
+                except typefinding.UnknownFileExtension:
+                    self.warning("Unknown file type: %s" % event.uri)
+                    self._drag_motion_result = False
+
+        return self._drag_motion_result
+    
+    def _viewport_drag_drop_event(self, viewport, event):
+        self._in_drag = False
+        files = []
+        for uri_string in event.uri:
+            uri = MediaUri(uri_string)
+            if uri.scheme == 'file':
+                #FIXME: shouldn't the unquote be handled in MediaUri?
+                files.append(unquote(uri.path))
+
+        main = self.retrieve_controllers('/poblesec')[0]
+        main.play_files(files)
+
+    def _viewport_drag_leave_event(self, viepwort, event):
+        self._in_drag = False
