@@ -6,10 +6,10 @@ packages, package_dir = find_packages(os.path.dirname(__file__))
 cmdclass = dict(test=TrialTest, clean=Clean)
 
 setup(name='elisa-plugin-pigment',
-    version='0.1', 
-    description='another pigment frontend',
+    version='0.4', 
+    description='Pigment frontend',
     long_description='another pigment frontend',
-    license='UNKNOWN', 
+    license='GPLv3', 
     author='Elisa Developers',
     author_email='elisa@lists.fluendo.com',
     keywords='',
