@@ -152,6 +152,9 @@ class TestGroup(TestCase):
 
         self.assertEqual(len(g), 0)
 
+    test_add_remove_drawables.todo = "Known issue in pigment: order not reset" \
+            " after removing drawable from a canvas."
+
     def test_add_remove_groups(self):
         g = Group()
         groups = []
@@ -370,18 +373,24 @@ class TestGroup(TestCase):
         parent = Group()
         self.assertEqual(parent.width, width0)
         self.assertEqual(parent.size[0], width0)
+        parent.width = width1
+        self.assertEqual(parent.width, width1)
+        self.assertEqual(parent.size[0], width1)
 
         child = Group()
-        self.assertEqual(parent.width, width0)
-        self.assertEqual(parent.size[0], width0)
+        self.assertEqual(child.width, width0)
+        self.assertEqual(child.size[0], width0)
         child.width = width1
         self.assertEqual(child.width, width1)
         self.assertEqual(child.size[0], width1)
 
-        # parenting preserves absolute width
+        # parenting preserves the value of the 'width' property while changing
+        # its meaning from absolute to relative
         parent.add(child)
-        self.assertEqual(child.absolute_width, width1)
-        self.assertEqual(child.absolute_size[0], width1)
+        self.assertEqual(child.width, width1)
+        self.assertEqual(child.size[0], width1)
+        self.assertNotEqual(child.absolute_width, width1)
+        self.assertNotEqual(child.absolute_size[0], width1)
 
         child.width = rel_width1
         self.assertEqual(child.width, rel_width1)
@@ -445,15 +454,19 @@ class TestGroup(TestCase):
         # one level nesting of groups
         parent = Group()
         self.assertEqual(parent.x, x0)
+        parent.x = x1
+        self.assertEqual(parent.x, x1)
 
         child = Group()
-        self.assertEqual(parent.x, x0)
+        self.assertEqual(child.x, x0)
         child.x = x1
         self.assertEqual(child.x, x1)
 
-        # parenting preserves absolute x
+        # parenting preserves the value of the 'x' property while changing
+        # its meaning from absolute to relative
         parent.add(child)
-        self.assertEqual(child.absolute_x, x1)
+        self.assertEqual(child.x, x1)
+        self.assertNotEqual(child.absolute_x, x1)
 
         child.x = rel_x1
         self.assertEqual(child.x, rel_x1)
@@ -535,14 +548,19 @@ class TestGroup(TestCase):
         self.assertEqual(real_x, x1)
 
         # parent group containing child group
-        # absolute x preserved for the children
+        # parenting preserves the value of the 'x' property while changing
+        # its meaning from absolute to relative
         parent = Group()
+        self.assertEqual(parent.x, x0)
+        parent.x = x1
+        self.assertEqual(parent.x, x1)
+
         parent.add(child)
 
-        self.assertEqual(parent.x, x0)
-        self.assertEqual(child.absolute_x, x1)
+        self.assertEqual(child.x, x1)
+        self.assertNotEqual(child.absolute_x, x1)
         real_x = image.get_position()[0]
-        self.assertEqual(real_x, x1)
+        self.assertEqual(real_x, child.x+parent.x)
 
         # moving parent group
         parent.x = x1
@@ -670,15 +688,19 @@ class TestGroup(TestCase):
         # one level nesting of groups
         parent = Group()
         self.assertEqual(parent.position, position0)
+        parent.position = position1
+        self.assertEqual(parent.position, position1)
 
         child = Group()
-        self.assertEqual(parent.position, position0)
+        self.assertEqual(child.position, position0)
         child.position = position1
         self.assertEqual(child.position, position1)
 
-        # parenting preserves absolute position
+        # parenting preserves the value of the 'position' property while changing
+        # its meaning from absolute to relative
         parent.add(child)
-        self.assertEqual(child.absolute_position, position1)
+        self.assertEqual(child.position, position1)
+        self.assertNotEqual(child.absolute_position, position1)
 
         child.position = rel_position1
         self.assertEqual(child.position, rel_position1)
@@ -738,15 +760,19 @@ class TestGroup(TestCase):
         # one level nesting of groups
         parent = Group()
         self.assertEqual(parent.size, size0)
+        parent.size = size1
+        self.assertEqual(parent.size, size1)
 
         child = Group()
-        self.assertEqual(parent.size, size0)
+        self.assertEqual(child.size, size0)
         child.size = size1
         self.assertEqual(child.size, size1)
 
-        # parenting preserves absolute size
+        # parenting preserves the value of the 'size' property while changing
+        # its meaning from absolute to relative
         parent.add(child)
         self.assertEqual(child.size, size1)
+        self.assertNotEqual(child.absolute_size, size1)
 
         child.size = rel_size1
         self.assertEqual(child.size, rel_size1)
