@@ -20,7 +20,6 @@ from twisted.python import reflect
 
 from elisa.core import common
 from elisa.core.config import Config
-from elisa.core.plugin_registry import PluginStatusMessage
 from elisa.core.utils.misc import pkg_resources_copy_dir
 
 from elisa.plugins.pigment.pigment_frontend import PigmentFrontendExtensionMixin
@@ -78,11 +77,18 @@ class ApplicationStub(object):
 
 class TestPigmentFrontendExtensionMixin(TestCase):
     def setUp(self):
-        common.application = ApplicationStub()
+        self._patch_application()
         self.frontend = PigmentFrontendExtensionMixin()
 
     def tearDown(self):
-        common.application = None
+        self._unpatch_application()
+
+    def _patch_application(self):
+        self._old_application = common.application
+        common.application = ApplicationStub()
+
+    def _unpatch_application(self):
+        common.application = self._old_application
 
     def test_create(self):
         """
@@ -399,7 +405,10 @@ class TestPigmentFrontendExtensionMixin(TestCase):
             return decorator_wait_dfr
 
         def create_controller_cb(controller):
-            return controller.clean()
+            dfr = controller.clean()
+            from elisa.plugins.pigment.widgets.theme import Theme
+            dfr.addCallback(lambda result: Theme.get_default().stop_monitoring())
+            return dfr
 
         self.frontend.add_controller('/elisa/album/.*', GenericAlbumController)
         self.frontend.add_decorator('/elisa/album/.*', slow_decorator)
@@ -446,11 +455,18 @@ class TestPigmentFrontendExtensionMixinMappings(TestCase):
         self.copy_plugin('tests/data/plugins/test_simple')
         self.load_plugins()
 
-        common.application = ApplicationStub()
+        self._patch_application()
         self.frontend = PigmentFrontendExtensionMixinStub()
 
     def tearDown(self):
-        common.application = None
+        self._unpatch_application()
+
+    def _patch_application(self):
+        self._old_application = common.application
+        common.application = ApplicationStub()
+
+    def _unpatch_application(self):
+        common.application = self._old_application
 
     def copy_plugin(self, path):
         # copy the plugin to _trial_temp/test_pigment_plugin
@@ -469,9 +485,13 @@ class TestPigmentFrontendExtensionMixinMappings(TestCase):
         """
         Test loading controller mappings from a fake plugin.
         """
+        plugin_name = 'elisa-plugin-test-pigment-frontend'
+        requirement = pkg_resources.Requirement.parse(plugin_name)
+        plugin = pkg_resources.working_set.find(requirement)
+        self.frontend.plugin_status_changed_cb(plugin, True)
+
         controller_mappings = set([("test_controller_key1", "test_controller_value1"),
                                    ("test_controller_key2", "test_controller_value2")])
-
         loaded = set(self.frontend.added_controllers)
         self.failUnless(controller_mappings.issubset(loaded))
 
@@ -479,6 +499,11 @@ class TestPigmentFrontendExtensionMixinMappings(TestCase):
         """
         Test loading decorator mappings from a fake plugin.
         """
+        plugin_name = 'elisa-plugin-test-pigment-frontend'
+        requirement = pkg_resources.Requirement.parse(plugin_name)
+        plugin = pkg_resources.working_set.find(requirement)
+        self.frontend.plugin_status_changed_cb(plugin, True)
+
         decorator_mappings = set([("test_decorator_key1", "test_decorator_value1"),
                                   ("test_decorator_key2", "test_decorator_value2")])
 
@@ -490,18 +515,19 @@ class TestPigmentFrontendExtensionMixinMappings(TestCase):
         Test disabling a plugin, then re-enabling it.
         """
         plugin_name = 'elisa-plugin-test-pigment-frontend'
+        requirement = pkg_resources.Requirement.parse(plugin_name)
+        plugin = pkg_resources.working_set.find(requirement)
 
         # Disable the plugin.
-        message = PluginStatusMessage(plugin_name,
-                                      PluginStatusMessage.ActionType.DISABLED)
-        self.frontend._plugin_status_changed_cb(message, None)
+        self.frontend.plugin_status_changed_cb(plugin, False)
         self.failUnlessEqual(len(self.frontend.added_controllers), 0)
         self.failUnlessEqual(len(self.frontend.added_decorators), 0)
 
+        # Try to disable it again. Nothing should happen.
+        self.frontend.plugin_status_changed_cb(plugin, False)
+
         # Re-enable the plugin.
-        message = PluginStatusMessage(plugin_name,
-                                      PluginStatusMessage.ActionType.ENABLED)
-        self.frontend._plugin_status_changed_cb(message, None)
+        self.frontend.plugin_status_changed_cb(plugin, True)
         controller_mappings = \
             set([('test_controller_key1', 'test_controller_value1'),
                  ('test_controller_key2', 'test_controller_value2')])
