@@ -81,11 +81,6 @@ class GridHorizontal(List):
                                   visible_range_size__set)
 
     def _create_widgets(self):
-         # FIXME: do not destroy and reload everything; support floats
-        for widget in self._widgets:
-            widget.clean()
-        self._widgets[:] = []
-
         nb_widgets = self._visible_range_size * self.rows + 2 * self.preloaded * self.rows
         for i in xrange(nb_widgets):
             widget = self._widget_class()
@@ -132,10 +127,12 @@ class GridHorizontal(List):
 
     def _prepare_widget(self, widget):
         widget.size = (self._item_width, self._item_height)
+        widget.position = (0.0, 0.0, 0.0)
 
     def _prepare_selector(self):
         if self._selector != None:
             self._selector.size = (self._item_width, self._item_height)
+            self._selector.position = (0.0, 0.0, 0.0)
 
     def _layout_widget(self, widget, row, column):
         x = self.compute_x(row, column)
