@@ -16,7 +16,7 @@
 
 from elisa.plugins.pigment.widgets.widget import Widget
 from elisa.plugins.pigment.widgets.const import *
-from elisa.plugins.pigment.widgets import notifying_list
+from elisa.core.utils import notifying_list
 
 from elisa.plugins.pigment.graph.image import Image
 from pgm.timing import implicit
@@ -135,7 +135,7 @@ class List(Widget):
                                              transformation=implicit.DECELERATE)
         self._animated.mode = implicit.REPLACE
 
-        self._update_style_properties(self._style.get_items())
+        self.update_style_properties(self.style.get_items())
 
     # Public API
 
@@ -156,7 +156,8 @@ class List(Widget):
             self.model.notifier.connect('items-inserted', self._on_items_inserted)
             self.model.notifier.connect('items-reordered', self._on_items_reordered)
 
-        self._render_all()
+        self._render_all_widgets()
+        self._layout_all_widgets()
         self._set_selector_visibility()
 
         # no item from self.model was selected, select the first one by default
@@ -175,7 +176,8 @@ class List(Widget):
         @type renderer: callable
         """
         self._renderer = renderer
-        self._render_all()
+        self._render_all_widgets()
+        self._layout_all_widgets()
 
     def set_selector(self, selector):
         if self._selector:
@@ -244,6 +246,7 @@ class List(Widget):
         start = max(widget_index, 0)
         end = len(self._widgets)
         self._render_widgets(start, end)
+        self._layout_all_widgets()
 
         self._set_selector_visibility()
 
@@ -270,11 +273,12 @@ class List(Widget):
         start = max(widget_index, 0)
         end = len(self._widgets)
         self._render_widgets(start, end)
+        self._layout_all_widgets()
 
         self._set_selector_visibility()
 
     def _on_items_reordered(self, notifier):
-        self._render_all()
+        self._render_all_widgets()
 
     def _move_widgets_from_beginning_to_end(self, number):
         moved = self._widgets[:number]
@@ -303,11 +307,8 @@ class List(Widget):
             if item_index >= 0 and item_index < len(self.model):
                 item = self.model[item_index]
                 gobject.idle_add(self._renderer, item, widget)
-                widget.visible = True
-            else:
-                widget.visible = False
 
-    def _render_all(self):
+    def _render_all_widgets(self):
         if self._render_all_call is not None:
             return
 
@@ -326,7 +327,7 @@ class List(Widget):
         delta = int(math.modf(visible_range_start)[1]-math.modf(old_start)[1])
 
         if abs(delta) >= len(self._widgets):
-            self._render_all()
+            self._render_all_widgets()
         elif delta >= 1:
             self._move_widgets_from_beginning_to_end(delta)
             self._render_widgets(len(self._widgets)-delta,
@@ -335,7 +336,8 @@ class List(Widget):
             self._move_widgets_from_end_to_beginning(-delta)
             self._render_widgets(0, -delta-1)
 
-        self._layout_all_widgets()
+        if visible_range_start != old_start:
+            self._layout_all_widgets()
 
     visible_range_start = property(visible_range_start__get, visible_range_start__set)
 
@@ -346,18 +348,22 @@ class List(Widget):
         assert (visible_range_size != 0)
         self._visible_range_size = visible_range_size
 
-        # FIXME: this is very suboptimal, we should not re-create all the
-        # widgets, only those that are needed
-        self._create_widgets()
-
         # set visible range start accordingly
         self._visible_range_start = self._selected_to_range_start(self._selected_item_index)
 
+        if self.absolute_visible:
+            self._create_and_render_all()
+
+    def _create_and_render_all(self):
+        # FIXME: this is very suboptimal, we should not re-create all the
+        # widgets, only those that are needed
+        self._destroy_widgets()
+        self._create_widgets()
+
         # FIXME: this is very suboptimal, we should not re-render all the
         # widgets, only those that are needed
-        self._render_all()
+        self._render_all_widgets()
 
-        self._prepare_all_widgets()
         self._layout_all_widgets()
         self._prepare_selector()
         self._layout_selector()
@@ -365,11 +371,6 @@ class List(Widget):
     visible_range_size = property(visible_range_size__get, visible_range_size__set)
 
     def _create_widgets(self):
-         # FIXME: do not destroy and reload everything; support floats
-        for widget in self._widgets:
-            widget.clean()
-        self._widgets[:] = []
-
         nb_widgets = self._visible_range_size+2*self.preloaded
         for i in xrange(nb_widgets):
             widget = self._widget_class()
@@ -378,6 +379,13 @@ class List(Widget):
             self._prepare_widget(widget)
             self._connect_widget(widget)
 
+    def _destroy_widgets(self):
+        # FIXME: the renderer might still be using or referencing the widgets
+        for widget in self._widgets:
+            self.remove(widget)
+            widget.clean()
+        self._widgets[:] = []
+
     def selected_item_index__get(self):
         return self._selected_item_index
 
@@ -432,30 +440,36 @@ class List(Widget):
         selected = maths.clamp(selected, 0, len(self.model)-1)
         return selected
 
-    def _layout_widget(self, widget, position):
-        raise NotImplementedError
-
-    def _prepare_all_widgets(self):
-        for widget in self._widgets:
-            self._prepare_widget(widget)
-
     def _prepare_widget(self, widget):
         pass
 
     def _prepare_selector(self):
         pass
 
+    def _layout_widget(self, widget, position):
+        raise NotImplementedError
+
     def _layout_all_widgets(self):
         if not self.absolute_visible:
             return
 
         # we assume that the widgets are created and loaded with their
         # corresponding data from the model
-        delta, start_item = math.modf(self._visible_range_start)
+        delta, start = math.modf(self._visible_range_start)
 
-        for i, widget in enumerate(self._widgets):
-            position = -delta + i - self.preloaded
-            self._layout_widget(widget, position)
+        i = -self.preloaded
+        for widget in self._widgets:
+            # only layout the widget if it is meant to be visible that is:
+            # - it does not belong to the preloaded widgets
+            # - it renders an item from the model
+            if i >= 0 and i <= self._visible_range_size and \
+               i+start >= 0 and i+start < len(self.model):
+                position = -delta + i
+                self._layout_widget(widget, position)
+                widget.visible = True
+            else:
+                widget.visible = False
+            i += 1
 
     def _layout_selector(self):
         if not self._selector:
@@ -492,21 +506,6 @@ class List(Widget):
         else:
             self._selector.visible = True
 
-    def compute_height(self, index):
-        raise NotImplementedError
-
-    def compute_width(self, index):
-        raise NotImplementedError
-
-    def compute_x(self, index):
-        raise NotImplementedError
-
-    def compute_y(self, index):
-        raise NotImplementedError
-
-    def compute_z(self, index):
-        return 0.0
-
     def compute_opacity(self, index):
         full_opacity = 255
         shaded_opacity = 100
@@ -544,10 +543,12 @@ class List(Widget):
     # Overridden from Group
 
     def visible__set(self, value):
-        old_value = self.absolute_visible
+        old_value = self.visible
         super(List, self).visible__set(value)
-        if self.absolute_visible and not old_value:
-            self._layout_all_widgets()
+        # FIXME: we work with the relative visible value here: this is not very
+        # reliable. We should use absolute_visible instead.
+        if value and not old_value:
+            self._create_and_render_all()
 
     visible = property(Widget.visible__get, visible__set)
 
@@ -645,7 +646,7 @@ class List(Widget):
     def _demo_widget(cls, *args, **kwargs):
         from elisa.plugins.pigment.graph.text import Text
         from elisa.plugins.pigment.graph.image import Image
-        from elisa.plugins.pigment.widgets.notifying_list import List
+        from elisa.core.utils.notifying_list import List
         import random
 
         widget = cls(Text)
