@@ -37,10 +37,11 @@ class ListHorizontal(List):
 
     def _prepare_widget(self, widget):
         widget.size = (self._item_width, self._item_height)
+        widget.position = (0.0, 0.0, 0.0)
 
     def _prepare_selector(self):
         if self._selector != None:
-            self._selector.y = 0.0
+            self._selector.position = (0.0, 0.0, 0.0)
             self._selector.size = (self._item_width, self._item_height)
 
     def _actual_layout_selector(self, selector, selected_item_index):
