@@ -71,19 +71,26 @@ class Range(Widget):
         self._set_cursor(Image())
         self._cursor.bg_color = self.style.cursor_color
 
-        self._update_style_properties(self._style.get_items())
-
-    def _update_style_properties(self, props=None):
-        super(Range, self)._update_style_properties(props)
+        self.update_style_properties(self.style.get_items())
 
+    def update_style_properties(self, props=None):
         if props is None:
             return
 
+        remaining_props = {}
+
         for key, value in props.iteritems():
             if key == 'background-color':
-                self._animated_background.bg_color = value
+                self._background.bg_color = value
             elif key == 'cursor-color':
-                self._animated_cursor.bg_color = value
+                self._cursor.bg_color = value
+            elif key in ('spacing_x', 'spacing_y'):
+                continue
+            else:
+                remaining_props[key] = value
+
+        if len(remaining_props) > 0:
+            return super(Range, self).update_style_properties(remaining_props)
 
     def _set_background(self, background):
         if self._background:
