@@ -17,6 +17,7 @@
 
 import gobject
 import weakref
+import copy
 
 
 class Style(gobject.GObject):
@@ -64,15 +65,14 @@ class Style(gobject.GObject):
         @param value: the property's value
         @type value: any
         """
-
+        old_key = key
         key = key.replace('-', '_')
-        super(Style, self).__setattr__(key, value)
+        gobject.GObject.__setattr__(self, key, value)
 
-        if not key.startswith('_') and key != 'widget':
-            key = key.replace('_', '-')
-            self._properties[key] = value
+        if key[0] != '_' and key != 'widget':
+            self._properties[old_key] = value
             if not self._initializing:
-                self.emit("property-changed", key, value)
+                self.emit("property-changed", old_key, value)
 
     def widget__set(self, value):
         if value is not None:
@@ -106,22 +106,16 @@ class Style(gobject.GObject):
         @returns:       the new style
         @rtype:         L{elisa.plugins.pigment.widgets.Style}
         """
-
         if inplace:
             new = self
         else:
             new = Style(**self._properties)
 
-        keys = self._properties.keys()
         for key, value in other:
             setattr(new, key, value)
 
         return new
 
-    def do_property_changed(self, key, value):
-        """Dummy 'property-changed' signal handler"""
-        return True
-
     def __iter__(self):
         return self._properties.iteritems()
 
@@ -146,6 +140,12 @@ class Style(gobject.GObject):
     def __repr__(self):
         return "Style: " + str(self._properties)
 
+    def __deepcopy__(self, memo):
+        new_style = Style()
+        new_style.widget = self.widget
+        new_style._properties = copy.deepcopy(self._properties, memo)
+        return new_style
+
 
 if __name__ == '__main__':
     style = Style()
