@@ -24,6 +24,7 @@ from elisa.core.utils import defer
 from elisa.core.utils.cancellable_defer import cancellable_deferred_iterator, \
         CancellableDeferred
 from elisa.plugins.base.models.image import ImageModel
+from elisa.plugins.base.models.media import PlaylistModel
 
 from twisted.internet import task
 
@@ -102,9 +103,10 @@ class PlayAllAction(Action):
         poblesec.show_music_player()
         self.controller.stop_loading_animation()
 
-        player.play_model(items[0])
-        for item in items[1:]:
-            player.enqueue_to_playlist(item)
+        playlist = PlaylistModel()
+        playlist.extend(items)
+        player.set_playlist(playlist)
+        player.play()
 
 
 class ShuffleAction(PlayAllAction):
@@ -208,7 +210,7 @@ class ActionPathNotSetError(Exception):
 
 
 class LinkAction(Action):
-
+    crumb_title = None
     path = None
     args = {}
 
@@ -216,8 +218,13 @@ class LinkAction(Action):
         if self.path is None:
             raise ActionPathNotSetError()
 
+        crumb_title = self.crumb_title
+        if crumb_title is None:
+            crumb_tile = self.title
+
         browser = self.controller.frontend.retrieve_controllers('/poblesec/browser')[0]
-        dfr = browser.history.append_controller(self.path, self.title, **self.args)
+        dfr = browser.history.append_controller(self.path, crumb_title,
+                                                **self.args)
 
         return dfr
 
