@@ -93,7 +93,7 @@ class CoverflowList(List):
         # center the items
         # assuming that each item has a reflection of the same height as
         # itself
-        widget.y = self._item_height/4.0
+        widget.position = (0.0, self._item_height/4.0, 0.0)
         widget.size = (self._item_width, self._item_height)
 
     def _layout_widget(self, widget, position):
@@ -119,6 +119,7 @@ class CoverflowList(List):
             widget.connect('clicked', self._fcl_child_clicked)
             self._widgets.append(widget)
             self.add(widget, forward_signals=False)
+            self._prepare_widget(widget)
 
     # Signals support methods
 
