@@ -17,7 +17,7 @@
 # Author: Olivier Tilloy <olivier@fluendo.com>
 
 from elisa.core.component import Component
-from elisa.plugins.pigment.widgets import notifying_list
+from elisa.core.utils import notifying_list
 
 from twisted.internet import task
 
@@ -48,7 +48,7 @@ class HierarchyController(Component):
     @type deferreds: C{dict} of C{list} of
                      {elisa.core.utils.cancellable_defer.CancellableDeferred}
     @ivar actions:   a list of contextual actions for this controller.
-    @type actions:   L{elisa.plugins.pigment.widgets.notifying_list.List} of
+    @type actions:   L{elisa.core.utils.notifying_list.List} of
                      L{elisa.plugins.poblesec.actions.Action}
     """
 
@@ -58,9 +58,9 @@ class HierarchyController(Component):
 
         # This call to super has to be done after the initialization of
         # self.actions, because it will take us into the hierarchy of the other
-        # superclass of the class inheriting from us - if present. Which may rely on the
-        # fact that self.actions are already up and filled.
-        # E.g.: see elisa.plugins.poblesec.base.preview_list.MenuItemPreviewListController
+        # superclass of the class inheriting from us - if present. Which may
+        # rely on the fact that self.actions are already up and filled (see
+        # elisa.plugins.poblesec.base.preview_list.MenuItemPreviewListController).
         deferred = super(HierarchyController, self).initialize()
 
         return deferred
