@@ -18,7 +18,7 @@ from elisa.core.component import Component
 from elisa.core.input_event import *
 
 from elisa.plugins.pigment.pigment_controller import PigmentController
-from elisa.plugins.pigment.widgets import notifying_list
+from elisa.core.utils import notifying_list
 from elisa.plugins.poblesec.widgets.nothing_to_display import NothingToDisplay
 from elisa.plugins.poblesec.actions import Action
 
