@@ -20,6 +20,7 @@ from elisa.core.utils.cancellable_defer import CancelledError
 from elisa.plugins.pigment.graph.image import Image
 from elisa.plugins.pigment.graph.text import Text
 from elisa.plugins.pigment.widgets.widget import Widget
+from elisa.core.utils import notifying_list
 from elisa.plugins.pigment.widgets.list_vertical import ListVertical
 
 from elisa.plugins.poblesec.base.list import ListController
@@ -35,30 +36,20 @@ from pgm.timing import implicit
 class Shortcut(Widget):
     def __init__(self):
         super(Shortcut, self).__init__()
+        self.font_color_enabled = None
+        self.font_color_disabled = None
 
         self.letter = Text()
         self.add(self.letter)
-        self.letter.width, self.letter.height = (1.0, 0.7)
-        x = 0.0
-        y = (1.0 - self.letter.height) / 2.0
-        self.letter.x, self.letter.y = (x, y)
-        self.letter.bg_color = (0, 0, 0, 0)
-        self.letter.alignment = pgm.TEXT_ALIGN_CENTER
-        self.letter.weight = pgm.TEXT_WEIGHT_BOLD
         self.letter.visible = True
 
-        self._update_style_properties(self._style.get_items())
+        self.update_style_properties(self.style.get_items())
 
-    def _update_style_properties(self, props=None):
-        super(Shortcut, self)._update_style_properties(props)
-
-        if props is None:
-            return
-
-        for key, value in props.iteritems():
-            if key == 'font-family':
-                self.letter.font_family = value
+    def enable(self):
+        self.letter.fg_color = self.font_color_enabled
 
+    def disable(self):
+        self.letter.fg_color = self.font_color_disabled
 
 class PreviewWidget(Widget):
     def __init__(self):
@@ -105,6 +96,17 @@ class PreviewWidget(Widget):
         self.source_label.alignment = pgm.TEXT_ALIGN_RIGHT
         self.source_label.visible = True
 
+    def clean(self):
+        self.source_label.clean()
+        self.source_label = None
+        self.source_icon.clean()
+        self.source_icon = None
+        self.reflection.clean()
+        self.reflection = None
+        self.image.clean()
+        self.image = None
+        return super(PreviewWidget, self).clean()
+
 
 class PreviewListController(ListController):
 
@@ -195,9 +197,9 @@ class PreviewListController(ListController):
 
     def _shortcut_renderer(self, shortcut, widget):
         if shortcut in self._get_active_shortcuts():
-            widget.letter.fg_color = (100, 100, 100, 255)
+            widget.enable()
         else:
-            widget.letter.fg_color = (20, 20, 20, 255)
+            widget.disable()
         widget.letter.label = shortcut.upper()
 
     def _get_current_shortcut(self):
@@ -232,12 +234,35 @@ class PreviewListController(ListController):
         #        is created in VerticalListController
         self.nodes.connect('selected-item-changed', self._initiate_load_preview)
 
+        if isinstance(self.nodes.model, notifying_list.List):
+            self._items_deleted_id = \
+                self.nodes.model.notifier.connect('items-deleted',
+                                                  self._on_items_deleted)
+
         if self.nodes.selected_item_index != -1:
             self._initiate_load_preview(self.nodes, None, None)
 
+    def clean(self):
+        if hasattr(self, '_items_deleted_id'):
+            self.nodes.model.notifier.disconnect(self._items_deleted_id)
+        self.animated_preview = None
+        self.preview.clean()
+        self.preview = None
+        if self.fastscroller:
+            self.fast_scroller.clean()
+            self.fast_scroller = None
+        self.nodes.clean()
+        self.nodes = None
+        return super(PreviewListController, self).clean()
+
     def image_from_item(self, item):
         return None
 
+    def _on_items_deleted(self, notifier, index, deleted):
+        if len(self.nodes.model) == 0:
+            self.animated_preview.stop_animations()
+            self.animated_preview.opacity = 0
+
     def _initiate_load_preview(self, widget, item, previous_item):
         # do not do anything if it was already fading out
         if self.animated_preview.opacity == 0.0:
