@@ -25,7 +25,7 @@ from elisa.plugins.base.models.device import VolumeModel
 from elisa.plugins.base.messages.device import NewDeviceDetected, \
                                                DeviceRemoved
 
-from elisa.plugins.pigment.widgets import notifying_list
+from elisa.core.utils import notifying_list
 
 from elisa.plugins.poblesec.filesystem import FilesystemPreviewListController
 from elisa.plugins.poblesec.base.preview_list import PreviewListController                                         
@@ -52,15 +52,17 @@ class MenuItem(object):
 
 
 class DirectoryConfigureController(PreviewListController):
-    
+
     node_widget = MenuItemWidgetWithAction
     list_widget = ActionListSelector
-    
+
     def initialize(self, **args):
         dfr = super(DirectoryConfigureController, self).initialize()
 
         uri = args['uri']
-        
+        self._refresh_cb = args['refresh_cb']
+        self._refresh_item = args['refresh_item']
+
         self.model = notifying_list.List()
         mi = MenuItem()
         mi.label = _("Add in Music Section")
@@ -68,29 +70,29 @@ class DirectoryConfigureController(PreviewListController):
         mi.icon = "elisa.plugins.poblesec.music_section"
         mi.uri = uri
         self.model.append(mi)
-        
+
         mi = MenuItem()
         mi.label = _("Add in Video Section")
         mi.media_type = "video"
         mi.icon = "elisa.plugins.poblesec.video_section"
         mi.uri = uri
         self.model.append(mi)
-        
+
         mi = MenuItem()
         mi.label = _("Add in Pictures Section")
         mi.media_type = "pictures"
         mi.icon = "elisa.plugins.poblesec.pictures_section"
         mi.uri = uri
         self.model.append(mi)
-        
+
         return dfr
-          
+
     def nodes_setup(self):
         super(DirectoryConfigureController,self).nodes_setup()
         #FIXME: why the renderer and the list are defined with class members
         #and not the selector ?
         self.selector = ActionSelector()
- 
+
         self.selector.create_cursor("item")
         self.selector.create_cursor("action")
 
@@ -137,7 +139,7 @@ class DirectoryConfigureController(PreviewListController):
                     item = self.model[index]
                     self.toggle_for_model(item, index)
                     return True
-    
+
         return super(DirectoryConfigureController,self).handle_input(manager, 
                                                                     input_event)
 
@@ -153,8 +155,8 @@ class DirectoryConfigureController(PreviewListController):
             index = self.model.index(model)
         self.model[index] = model
 
-        # FIXME: Refresh the toggled state of the folder in the parent
-        # controller (see https://bugs.launchpad.net/elisa/+bug/244314).
+        # Refresh the state of the item in the parent controller.
+        self._refresh_cb(self._refresh_item)
 
 
 class MediaDirectoryList(SectionMenuController):
@@ -200,6 +202,7 @@ class MediaDirectoryList(SectionMenuController):
         add_directory.label = _("Add folders")
         add_directory.icon = "elisa.plugins.poblesec.directory_settings_add_folder"
         add_directory.controller_args = {'media_type': media_type}
+        self.model.append(add_directory)
 
     def _focus_cb(self, widget, focus):
         if focus:
@@ -231,18 +234,27 @@ class DirectorySettingsController(FilesystemPreviewListController):
 
                 return self
 
-            def load_items(controller):
+            def failed_get_devices(failure):
+                self.warning('Failed to retrieve the list of devices: %s.' % \
+                             failure)
+                return self
+
+            def add_home(result):
                 home = DirectoryModel()
                 home.name = _('Home')
                 home.uri = HOME_URI
-                controller.model.append(home)
+                self.model.append(home)
+                return result
 
+            def get_devices(result):
                 devices_uri = MediaUri('volumes://localhost/?filter=file')
                 devices, dfr_devices = application.resource_manager.get(devices_uri)
-                dfr_devices.addCallback(got_devices)
                 return dfr_devices
 
-            dfr.addCallback(load_items)
+            dfr.addCallback(add_home)
+            dfr.addCallback(get_devices)
+            dfr.addCallback(got_devices)
+            dfr.addErrback(failed_get_devices)
 
         return dfr
 
@@ -332,11 +344,17 @@ class DirectorySettingsController(FilesystemPreviewListController):
                                                     (file_uri, self.media_type)
             self.model[index] = model
         else:
-            # we assume there was only one controller created with that path
-            controllers = self.frontend.retrieve_controllers('/poblesec/browser')
-            browser = controllers[0]
+            browser = self.frontend.retrieve_controllers('/poblesec/browser')[0]
             path = '/poblesec/settings/directory_selection_settings'
-            dfr = browser.history.append_controller(path, model.name, uri=file_uri)
+            args = {'uri': file_uri,
+                    'refresh_cb': self._refresh_cb,
+                    'refresh_item': model}
+            dfr = browser.history.append_controller(path, model.name, **args)
+
+    def _refresh_cb(self, item):
+        # This trick triggers a re-rendering of the item's widget.
+        index = self.model.index(item)
+        self.model[index] = item
 
     def handle_input(self, manager, input_event):
         if  self.nodes.focus:
