@@ -107,7 +107,7 @@ class History(gobject.GObject, Loggable):
         return cancellable_dfr
 
     def go_back(self):
-        if not self.current:
+        if not self.current or self.index < 1:
             self.warning("No current controller in this history.")
             return
 
