@@ -59,7 +59,7 @@ class LoginSettingsController(PigmentController):
                                      (str,)),
                    }
 
-    def initialize(self, service):
+    def initialize(self, service=None):
         dfr = super(LoginSettingsController, self).initialize()
 
         self.service = service
@@ -250,9 +250,10 @@ class LoginSettingsController(PigmentController):
 
 class UsernameSettingsController(LoginSettingsController):
 
-    def initialize(self, service, password_controller, login_result_controller,
+    def initialize(self, service=None, password_controller=None,
+                   login_result_controller=None,
                    try_login=None, login_actions=[]):
-        dfr = super(UsernameSettingsController, self).initialize(service)
+        dfr = super(UsernameSettingsController, self).initialize(service=service)
 
         self.password_controller = password_controller
         self.login_result_controller = login_result_controller
@@ -280,8 +281,9 @@ class UsernameSettingsController(LoginSettingsController):
 
 class PasswordSettingsController(LoginSettingsController):
 
-    def initialize(self, service, username, login_result_controller, try_login, login_actions):
-        dfr = super(PasswordSettingsController, self).initialize(service)
+    def initialize(self, service=None, username=None,
+                   login_result_controller=None, try_login=None, login_actions=[]):
+        dfr = super(PasswordSettingsController, self).initialize(service=service)
 
         self.service = service
         self.username = username
@@ -358,7 +360,7 @@ class ReturnButton(Widget):
 
 class LoginResultController(PigmentController):
 
-    def initialize(self, result, service, login_actions):
+    def initialize(self, result=None, service=None, login_actions=None):
         dfr = super(LoginResultController, self).initialize()
 
         self.result = result
