@@ -25,10 +25,14 @@ from elisa.plugins.gstreamer.amp_master import GstMetadataAmpClient
 from elisa.plugins.base.models.media import PlayableModel
 from elisa.plugins.base.models.image import ImageModel
 
+from elisa.plugins.pigment.message import PigmentFrontendLoadedMessage
+
 from elisa.core.input_event import *
 from elisa.core.utils import defer
-from elisa.core.application import NewElisaVersionMessage, FirstRunMessage, \
-                                   CONFIG_DIR
+from elisa.core.default_config import CONFIG_DIR
+from elisa.core.application import NewElisaVersionMessage
+from elisa.core.utils.update_checker import AvailablePluginUpdatesMessage
+
 from elisa.core import common
 from elisa.core.utils import typefinding
 from elisa.core.utils.i18n import install_translation
@@ -38,6 +42,11 @@ _ = install_translation('poblesec')
 import platform
 import os
 
+from twisted.internet import task
+
+import pgm
+
+
 try:
     import dbus
     from elisa.plugins.poblesec.dbus_player import Player as DBusPlayer
@@ -86,8 +95,11 @@ class PoblesecController(PigmentController):
         self._popups_enabled = True
 
     def initialize(self):
-        common.application.bus.register(self._got_new_version, NewElisaVersionMessage)
-        common.application.bus.register(self._first_run_notification, FirstRunMessage)
+        bus = common.application.bus
+        bus.register(self._got_new_version, NewElisaVersionMessage)
+        bus.register(self._frontend_loaded, PigmentFrontendLoadedMessage)
+        bus.register(self._plugin_updates_available,
+                     AvailablePluginUpdatesMessage)
         return super(PoblesecController, self).initialize()
 
     def _got_new_version(self, message, sender):
@@ -134,14 +146,17 @@ class PoblesecController(PigmentController):
         buttons = [(_('Yes'), ok_clicked), (_('Later'), self.hide_popup)]
         self.enqueue_popup(icon, title, text, buttons)
 
-    def _first_run_notification(self, message, sender):
-        self.debug('First run notification, showing the configuration wizard')
+    def _frontend_loaded(self, message, sender):
+        if not common.application.first_run:
+            return
+        self.debug('First run, showing the configuration wizard')
 
         # While the wizard is visible, no popups can be shown
         #self.enable_popups(False)
 
         def start_wizard(wizard):
-            self._wizard_close_handler_id = wizard.connect('closed', self._close_wizard_cb)
+            self._wizard_close_handler_id = wizard.connect('closed',
+                                                           self._close_wizard_cb)
             wizard.set_frontend(self.frontend)
             return wizard.start()
 
@@ -182,6 +197,197 @@ class PoblesecController(PigmentController):
 
         return self._background_out.apply(wizard).addCallback(faded)
 
+    def _plugin_updates_available(self, message, sender):
+        # Plugin updates and/or new recommended plugins are available for
+        # download from the plugin repository.
+
+        def iterate_plugins(available_updates, new_recommended, updated):
+            plugin_registry = common.application.plugin_registry
+
+            def _plugin_updated(result, plugin_dict):
+                self.debug('Updated %s to version %s.' % \
+                           (plugin_dict['name'], plugin_dict['version']))
+                updated.append(plugin_dict['name'])
+                return result
+
+            def _update_failed(failure, plugin_dict):
+                self.debug('Failed to update %s to version %s.' % \
+                           (plugin_dict['name'], plugin_dict['version']))
+                # Swallow the failure, to go on with the remaining updates.
+                return None
+
+            for plugin_dict in available_updates:
+                dfr = plugin_registry.update_plugin(plugin_dict)
+                dfr.addCallback(_plugin_updated, plugin_dict)
+                dfr.addErrback(_update_failed, plugin_dict)
+                yield dfr
+
+            def _plugin_installed(result, plugin_dict):
+                self.debug('Installed %s %s.' % \
+                           (plugin_dict['name'], plugin_dict['version']))
+                return result
+
+            def _install_failed(failure, plugin_dict):
+                self.debug('Failed to install %s %s.' % \
+                           (plugin_dict['name'], plugin_dict['version']))
+                # Swallow the failure, to go on with the remaining plugins.
+                return None
+
+            def _install_plugin(egg_file, plugin_dict):
+                install_dfr = \
+                    plugin_registry.install_plugin(egg_file,
+                                                   plugin_dict['name'])
+                install_dfr.addErrback(_install_failed)
+                return install_dfr
+
+            for plugin_dict in new_recommended:
+                dfr = plugin_registry.download_plugin(plugin_dict)
+                dfr.addCallback(_install_plugin, plugin_dict)
+                dfr.addCallback(_plugin_installed, plugin_dict)
+                yield dfr
+
+        def process_plugins(result, updates, new, updated):
+            return task.coiterate(iterate_plugins(updates, new, updated))
+
+        def show_restart_popup(result, updated):
+            if len(updated) == 0:
+                # Restart is needed only for plugin updates
+                return result
+
+            icon = 'elisa.plugins.poblesec.plugin'
+            title = _('Need To Restart Elisa')
+            if len(updated) == 1:
+                text = _('An update has been installed. For it to take ' \
+                         'effect, please exit and restart Elisa.')
+            else:
+                text = _('%d updates have been installed. For them to ' \
+                         'take effect, please exit and restart Elisa.') % \
+                         len(updated)
+
+            buttons = [(_('OK'), self.hide_popup)]
+            import sys
+            if platform.system() == 'Windows' and hasattr(sys, 'frozen'):
+                # Running an installed Elisa on Windows: we are able to restart
+                # Elisa automatically.
+                buttons[0] = (_('Later'), self.hide_popup)
+                from mswin32 import tools
+                restart_button = (_('Restart'), lambda: tools.exit(1, True))
+                buttons.insert(0, restart_button)
+
+            self.enqueue_popup(icon, title, text, buttons)
+            return result
+
+        def do_process_plugins(updates, new):
+            if self._popup_visible:
+                dfr = self.hide_popup()
+            else:
+                dfr = defer.succeed(None)
+            updated = []
+            dfr.addCallback(process_plugins, updates, new, updated)
+            dfr.addCallback(show_restart_popup, updated)
+            return dfr
+
+        config = common.application.config
+        silent_update = \
+            config.get_option('auto_update_plugins', section='plugin_registry')
+        silent_install = \
+            config.get_option('auto_install_new_recommended_plugins',
+                              section='plugin_registry')
+
+        if silent_update and silent_install:
+            # Do not ask the user's confirmation
+            return do_process_plugins(message.available_updates,
+                                      message.new_recommended)
+
+        elif silent_update:
+            if len(message.new_recommended) == 0:
+                return do_process_plugins(message.available_updates, [])
+
+            # Ask the user's confirmation to install new recommended plugins
+            title = _('New Recommended Plugins Available')
+            if len(message.new_recommended) == 1:
+                text = _('A new recommended plugin is available for ' \
+                         'installation. Do you want to install it?')
+            else:
+                text = _('%d new recommended plugins are available for ' \
+                         'installation. Do you want to install them?') % \
+                         len(message.new_recommended)
+            icon = 'elisa.plugins.poblesec.plugin'
+            buttons = [(_('Now'),
+                        lambda: do_process_plugins(message.available_updates,
+                                                   message.new_recommended)),
+                       (_('Later'),
+                        lambda: do_process_plugins(message.available_updates,
+                                                   []))]
+            return self.enqueue_popup(icon, title, text, buttons)
+
+        elif silent_install:
+            if len(message.available_updates) == 0:
+                return do_process_plugins([], message.new_recommended)
+
+            # Ask the user's confirmation to update plugins
+            title = _('Updates Available')
+            if len(message.available_updates) == 1:
+                text = _('An update is available for installation. ' \
+                         'Do you want to install it?')
+            else:
+                text = _('%d updates are available for installation. ' \
+                         'Do you want to install them?') % \
+                         len(message.available_updates)
+            icon = 'elisa.plugins.poblesec.plugin'
+            buttons = [(_('Now'),
+                        lambda: do_process_plugins(message.available_updates,
+                                                   message.new_recommended)),
+                       (_('Later'),
+                        lambda: do_process_plugins([],
+                                                   message.new_recommended))]
+            return self.enqueue_popup(icon, title, text, buttons)
+
+        if len(message.new_recommended) == 0:
+            title = _('Updates Available')
+            if len(message.available_updates) == 1:
+                text = _('An update is available for installation. ' \
+                         'Do you want to install it?')
+            else:
+                text = _('%d updates are available for installation. ' \
+                         'Do you want to install them?') % \
+                         len(message.available_updates)
+        elif len(message.available_updates) == 0:
+            title = _('New Recommended Plugins Available')
+            if len(message.new_recommended) == 1:
+                text = _('A new recommended plugin is available for ' \
+                         'installation. Do you want to install it?')
+            else:
+                text = _('%d new recommended plugins are available for ' \
+                         'installation. Do you want to install them?') % \
+                         len(message.new_recommended)
+        else:
+            title = _('Updates and New Recommended Plugins Available')
+            if len(message.available_updates) == 1 and \
+                len(message.new_recommended) == 1:
+                text = _('An update and a new recommended plugin are ' \
+                 'available for installation. Do you want to install them?')
+            elif len(message.available_updates) == 1:
+                text = _('An update and %d new recommended plugins ' \
+                         'are available for installation. Do you want to ' \
+                         'install them?') % len(message.new_recommended)
+            elif len(message.new_recommended) == 1:
+                text = _('%d updates and a new recommended plugin ' \
+                         'are available for installation. Do you want to ' \
+                         'install them?') % len(message.available_updates)
+            else:
+                text = _('%d updates and %d new recommended plugins ' \
+                         'are available for installation. Do you want to ' \
+                         'install them?') % (len(message.available_updates), \
+                                             len(message.new_recommended))
+
+        icon = 'elisa.plugins.poblesec.plugin'
+        buttons = [(_('Now'),
+                    lambda: do_process_plugins(message.available_updates,
+                                               message.new_recommended)),
+                   (_('Later'), self.hide_popup)]
+        self.enqueue_popup(icon, title, text, buttons)
+
     def set_frontend(self, frontend):
         super(PoblesecController, self).set_frontend(frontend)
         
@@ -204,6 +410,7 @@ class PoblesecController(PigmentController):
         def video_player_created(controller):
             self.video_player = controller
             self.current_player = controller
+            self.video_player.widget.layer = pgm.DRAWABLE_FAR
             self.widget.add(self.video_player.widget)
             self.video_player.widget.width = 1.0
             self.video_player.widget.height = 1.0
@@ -219,6 +426,7 @@ class PoblesecController(PigmentController):
         def dvd_player_created(controller):
             self.dvd_player = controller
             self.current_player = controller
+            self.dvd_player.widget.layer = pgm.DRAWABLE_FAR
             self.widget.add(self.dvd_player.widget)
             self.dvd_player.widget.width = 1.0
             self.dvd_player.widget.height = 1.0
@@ -241,6 +449,7 @@ class PoblesecController(PigmentController):
 
         def music_player_created(controller):
             self.music_player = controller
+            self.music_player.widget.layer = pgm.DRAWABLE_FAR
             self.widget.add(self.music_player.widget)
             self.music_player.widget.width = 1.0
             self.music_player.widget.height = 1.0
@@ -255,6 +464,7 @@ class PoblesecController(PigmentController):
 
         def slideshow_player_created(controller):
             self.slideshow_player = controller
+            self.slideshow_player.widget.layer = pgm.DRAWABLE_FAR
             self.widget.add(self.slideshow_player.widget)
             self.slideshow_player.widget.width = 1.0
             self.slideshow_player.widget.height = 1.0
@@ -274,7 +484,7 @@ class PoblesecController(PigmentController):
     def _process_command_line_files(self, result):
         files = common.application.options['files']
         if len(files) > 0:
-            self.play_file(files[0])
+            self.play_files(files)
 
     def _create_gst_metadata(self):
         def gst_metadata_created(gst_metadata):
@@ -290,16 +500,21 @@ class PoblesecController(PigmentController):
             return
 
         bus = dbus.SessionBus()
+        self.bus_name = dbus.service.BusName('com.fluendo.Elisa', bus)
 
         self.dbus_player = DBusPlayer(self, bus,
-                '/com/fluendo/Elisa/Plugins/Poblesec/AudioPlayer')
+                '/com/fluendo/Elisa/Plugins/Poblesec/AudioPlayer', self.bus_name)
         
         from elisa.plugins.poblesec.dbus_player import FilePlayer
         self.dbus_fileplayer = FilePlayer(self, bus,
-                '/com/fluendo/Elisa/Plugins/Poblesec/FilePlayer')
+                '/com/fluendo/Elisa/Plugins/Poblesec/FilePlayer', self.bus_name)
 
     def clean(self):
         self._clean_dbus()
+        bus = common.application.bus
+        bus.unregister(self._plugin_updates_available)
+        bus.unregister(self._frontend_loaded)
+        bus.unregister(self._got_new_version)
         return super(MainController, self).clean()
 
     def _clean_dbus(self):
@@ -312,6 +527,8 @@ class PoblesecController(PigmentController):
                 '/com/fluendo/Elisa/Plugins/Poblesec/AudioPlayer')
         self.dbus_fileplayer.remove_from_connection(bus,
                 '/com/fluendo/Elisa/Plugins/Poblesec/FilePlayer')
+        # BusName implements __del__, eew
+        del self.bus_name
 
         # remove the reference cycle
         self.dbus_player = None
@@ -501,10 +718,23 @@ class PoblesecController(PigmentController):
         self.dvd_player.player.stop()
 
     def handle_input(self, manager, input_event):
-
+        if input_event.value == EventValue.KEY_OK and \
+                input_event.modifier == EventModifier.ALT:
+            self.frontend.viewport.fullscreen = not self.frontend.viewport.fullscreen
+            return True
+        
         if self.focused_controller.handle_input(manager, input_event):
             return True
-
+        
+        if input_event.value == EventValue.KEY_ESCAPE:
+            self.frontend.viewport.fullscreen = not self.frontend.viewport.fullscreen
+            return True
+        elif input_event.value == EventValue.KEY_F11:
+            self.frontend.viewport.fullscreen = not self.frontend.viewport.fullscreen
+            return True
+        elif input_event.value == EventValue.KEY_f:
+            self.frontend.viewport.fullscreen = not self.frontend.viewport.fullscreen
+            return True
         elif input_event.value == EventValue.KEY_MENU:
             if self.focused_controller == self.browser:
                 if self.current_player.player.status != \
@@ -521,14 +751,33 @@ class PoblesecController(PigmentController):
 
         return super(PoblesecController, self).handle_input(manager, input_event)
     
-    def play_file(self, file_path):
+    def get_playable_model(self, file_path):
+        file_uri = MediaUri("file://%s" % file_path)
+        playable_model = PlayableModel()
+        playable_model.uri = file_uri
+        playable_model.title = os.path.basename(file_path)
+        return playable_model
+    
+    def get_image_model(self, file_path):
+        file_uri = MediaUri("file://%s" % file_path)
+        image = ImageModel()
+        image.references.append(file_uri)
+        image.title = file_path
+        return image
+    
+    def play_files(self, files):
+        #import pdb; pdb.set_trace()
+        try:
+            file_path = files[0]
+        except IndexError, e:
+            return
         try:
             file_uri = MediaUri("file://%s" % file_path)
             media_type = typefinding.typefind(file_uri)
         except typefinding.UnknownFileExtension, e:
             self.warning("Can't retrieve file type: %s" % file_path)
             return
-            
+         
         playable_model = PlayableModel()
         playable_model.uri = file_uri
         playable_model.title = os.path.basename(file_path)
@@ -536,15 +785,24 @@ class PoblesecController(PigmentController):
         if "video" in media_type:
             self.video_player.player.play_model(playable_model)
             self.show_video_player()
+            for file in files[1:]:
+                playable_model = self.get_playable_model(file)
+                self.video_player.player.enqueue_to_playlist(playable_model)
         elif "audio" in media_type:
             self.music_player.player.play_model(playable_model)
             self.show_music_player()
+            for file in files[1:]:
+                playable_model = self.get_playable_model(file)
+                self.music_player.player.enqueue_to_playlist(playable_model)
         elif "image" in media_type:
             self.slideshow_player.player.clear_playlist()
             image = ImageModel()
             image.references.append(file_uri)
             image.title = file_path
             self.slideshow_player.player.enqueue_to_playlist(image)
+            for file in files[1:]:
+                image = self.get_image_model(file)
+                self.slideshow_player.player.enqueue_to_playlist(image)
             self.show_slideshow_player()
         else:
             self.warning("Unknown media type: %s" % file_path)
