@@ -18,30 +18,25 @@
 #          Benjamin Kampmann <benjamin@fluendo.com>
 
 from elisa.core.media_uri import MediaUri
-from elisa.plugins.poblesec.link import Link
-
-from elisa.plugins.base.models.media import PlayableModel
-from elisa.plugins.poblesec.base.preview_list import MenuItemPreviewListController, \
-    DoubleLineMenuItemPreviewListController
-from elisa.plugins.poblesec.base.list import ListController, GenericListViewMode
-
+from elisa.core.log import Loggable
 from elisa.core import common
-from elisa.core.application import PICTURES_CACHE
-
+from elisa.core.default_config import PICTURES_CACHE
+from elisa.core.utils import defer
 from elisa.core.utils.cancellable_defer import CancelledError
-
 from elisa.core.resource_manager import NoMatchingResourceProvider, \
                                         ResourceProviderNotFound
+
 from elisa.plugins.base.models.audio import AlbumModel
 
+from elisa.plugins.poblesec.link import Link
+from elisa.plugins.poblesec.base.list import GenericListViewMode
+
 # FIXME: cover retrieval is hardcoded for amazon covers
 try:
     from elisa.plugins.amazon.metadata import AmazonCovers
 except ImportError:
     AmazonCovers = None
 
-from elisa.core.utils import defer
-
 import os
 
 try:
@@ -82,8 +77,9 @@ class AlreadyInQueueError(Exception):
     pass
 
 
-class ArtistPictureRetriever(object):
+class ArtistPictureRetriever(Loggable):
     def __init__(self):
+        super(ArtistPictureRetriever, self).__init__()
         self.enabled = True
         self.cache = {}
 
@@ -140,7 +136,8 @@ class ArtistPictureRetriever(object):
             elif self._check_for_image_on_model(model, model_id):
                 return model
 
-            return failure
+            self.debug('Failed to retrieve artist picture for %s: %s' % \
+                       (model.name, failure))
 
         try:
             data_model, dfr = common.application.resource_manager.get(uri)
@@ -158,8 +155,9 @@ class ArtistPictureRetriever(object):
 artist_picture_retriever = ArtistPictureRetriever()
 
 
-class AlbumCoverRetrieval(object):
+class AlbumCoverRetrieval(Loggable):
     def __init__(self):
+        super(AlbumCoverRetrieval, self).__init__()
         self.cache = {}
         self.provider = None
 
@@ -231,7 +229,8 @@ class AlbumCoverRetrieval(object):
             elif self._check_for_cover_on_model(model, model_id):
                 return model
 
-            return defer.fail(failure)
+            self.debug('Failed to retrieve album cover for %s: %s' % \
+                       (model.name, failure))
 
         deferred = self.provider.get_metadata(album_model)
         deferred.addCallback(got_cover_uri, model, model_id)
@@ -299,6 +298,9 @@ class AlbumsViewMode(GenericListViewMode):
         resource = 'elisa.plugins.poblesec.cover'
         return resource
 
+    def get_sublabel(self, item):
+        return item.get_artist_name()
+
     def get_image(self, item, theme):
         def got_artist(artist):
             return album_cover_retriever.get_cover_uri(item, artist)
