@@ -18,7 +18,6 @@ from elisa.core.input_event import *
 from elisa.core.log import Loggable
 from elisa.core.common import application
 from elisa.core.utils import defer, cancellable_defer
-from elisa.core.application import PICTURES_CACHE
 from elisa.core.media_uri import MediaUri
 
 from elisa.plugins.base.models.file import FileModel
@@ -27,7 +26,7 @@ from elisa.plugins.base.models.media import RawDataModel
 from elisa.plugins.pigment.pigment_controller import PigmentController
 from elisa.plugins.pigment.graph.image import Image
 from elisa.plugins.pigment.widgets.list import List
-from elisa.plugins.pigment.widgets import notifying_list
+from elisa.core.utils import notifying_list
 from elisa.plugins.pigment.widgets.list_horizontal import ListHorizontal
 from elisa.plugins.poblesec.player_video import PlayerOsd as VideoPlayerOsd
 from elisa.plugins.poblesec.videoplayer_controls import PlayPauseControl, \
@@ -187,13 +186,6 @@ class Slideshow(gobject.GObject, Loggable):
         self.background.set_renderer(self._renderer)
         self.background.visible = True
 
-        # pictures cache directory management
-        try:
-            os.makedirs(PICTURES_CACHE)
-        except OSError:
-            # cache directory already existing
-            pass
-
     def _renderer(self, item, widget):
 
         # should cancel previous dfr_thumbnail and dfr_full created for widget
@@ -234,14 +226,12 @@ class Slideshow(gobject.GObject, Loggable):
             self._load_from_theme(icon, widget.quick_image)
 
     def _retrieve_thumbnail(self, item):
-        uri = item.references[0]
-        self.debug("retrieving thumbnail image from %s" % uri)
-        return self._retrieve_and_cache(uri)
+        #self.debug("retrieving thumbnail image from %s" % uri)
+        return item.get_cached_data_path(0)
 
     def _retrieve_full_resolution(self, item):
-        uri = item.references[-1]
-        self.debug("retrieving full resolution image from %s" % uri)
-        return self._retrieve_and_cache(uri)
+        #self.debug("retrieving full resolution image from %s" % uri)
+        return item.get_cached_data_path(-1)
 
     def _update_playcount_and_time(self, uri):
         if uri.scheme != 'file':
@@ -310,27 +300,6 @@ class Slideshow(gobject.GObject, Loggable):
         dfr.addCallback(update)
         return dfr
 
-    def _retrieve_and_cache(self, uri):
-        path = self._compute_cached_path(uri)
-
-        if os.path.exists(path):
-            self.debug("%s already cached at %s", uri, path)
-            # already cached
-            dfr = defer.Deferred()
-            dfr.callback(path)
-        else:
-            def cache_it(result):
-                if isinstance(result, RawDataModel):
-                    self._cache_raw_data(result.data, path)
-                    return path
-                elif isinstance(result, FileModel):
-                    return result.uri.path
-
-            model, dfr = application.resource_manager.get(uri)
-            dfr.addCallback(cache_it)
-
-        return dfr
-
     def _load_thumbnail(self, path, widget):
         # downscaling to 1024 is our safety net here in case some broken
         # resource provider is used
@@ -345,19 +314,6 @@ class Slideshow(gobject.GObject, Loggable):
         # than the viewport size nor 1024
         widget.image.set_from_file(path, 1024)
 
-    def _compute_cached_path(self, uri):
-        filename = md5.new(str(uri)).hexdigest() + '.' + uri.extension
-        path = os.path.join(PICTURES_CACHE, filename)
-        return path
-
-    def _cache_raw_data(self, data, path):
-        self.debug("caching image at %s", path)
-        if not os.path.exists(PICTURES_CACHE):
-            os.makedirs(PICTURES_CACHE, 0755)
-        fd = open(path, 'wb')
-        fd.write(data)
-        fd.close()
-
     def _cancel_last_call_later(self):
         if self._call_later != None and self._call_later.active():
             self._call_later.cancel()
