@@ -21,6 +21,7 @@ from elisa.plugins.pigment.widgets.theme import Theme
 from elisa.plugins.pigment.graph.image import Image
 from elisa.plugins.pigment.graph.text import Text
 
+from elisa.plugins.poblesec.base.list_switcher import ListSwitcherController
 from elisa.plugins.poblesec.browser_controller import BrowserController
 from elisa.core.input_event import *
 
@@ -51,7 +52,7 @@ class TopBarButton(Widget):
         self.coverflow_button = self._create_image()
         self.grid_button = self._create_image()
         
-        self._update_style_properties(self._style.get_items())
+        self.update_style_properties(self.style.get_items())
         
     def _create_image(self):
         image =  Image()
@@ -78,14 +79,14 @@ class TopBarButton(Widget):
         if self.index > -1:
             self._buttons[self.index].fg_a = 255
 
-    def _update_style_properties(self, props=None):
-        super(TopBarButton, self)._update_style_properties(props)
-
+    def update_style_properties(self, props=None):
         if props is None:
             return
 
         theme = Theme.get_default()
 
+        remaining_props = {}
+
         # FIXME: bad prefix 'top-bar-', has just to be dropped
         for key, value in props.iteritems():
             if key == 'button-height':
@@ -118,6 +119,8 @@ class TopBarButton(Widget):
                 self.grid_button.width, self.grid_button.height = width, height
                 self.grid_button.x = x_offset
                 self.grid_button.y = (1.0 - height) / 2.0
+            elif key in ('button-width', 'space'):
+                continue
             elif key == 'top-bar-play-button':
                 self.play_button.set_from_file(theme.get_resource(value))
             elif key == 'top-bar-stop-button':
@@ -128,6 +131,11 @@ class TopBarButton(Widget):
                 self.coverflow_button.set_from_file(theme.get_resource(value))
             elif key == 'top-bar-grid-button':
                 self.grid_button.set_from_file(theme.get_resource(value))
+            else:
+                remaining_props[key] = value
+
+        if len(remaining_props) > 0:
+            return super(TopBarButton, self).update_style_properties(remaining_props)
 
 
 class TopBar(Widget):
@@ -159,16 +167,17 @@ class TopBar(Widget):
         self.text.bg_a = 0
         self.text.visible = True
         
-        self._update_style_properties(self._style.get_items())
+        self.update_style_properties(self.style.get_items())
 
-    def _update_style_properties(self, props=None):
-        super(TopBar, self)._update_style_properties(props)
+    def update_style_properties(self, props=None):
 
         if props is None:
             return
 
         theme = Theme.get_default()
 
+        remaining_props = {}
+
         # FIXME: bad prefix 'top-bar-', has just to be dropped
         for key, value in props.iteritems():
             if key == 'top-bar-buttons-x':
@@ -193,6 +202,11 @@ class TopBar(Widget):
                 self.text.font_family = value
             elif key == 'top-bar-background':
                 self.background.set_from_file(theme.get_resource(value))
+            else:
+                remaining_props[key] = value
+
+        if len(remaining_props) > 0:
+            return super(TopBar, self).update_style_properties(remaining_props)
 
 
 class BottomBar(Widget):
@@ -232,19 +246,24 @@ class BottomBar(Widget):
         self.animated.setup_next_animations(**settings)
         self.animated.mode = implicit.REPLACE
         
-        self._update_style_properties(self._style.get_items())
-
-    def _update_style_properties(self, props=None):
-        super(BottomBar, self)._update_style_properties(props)
+        self.update_style_properties(self.style.get_items())
 
+    def update_style_properties(self, props=None):
         if props is None:
             return
 
         theme = Theme.get_default()
 
+        remaining_props = {}
+
         for key, value in props.iteritems():
             if key == 'back-button-image':
                 self.back_button.set_from_file(theme.get_resource(value))
+            else:
+                remaining_props[key] = value
+
+        if len(remaining_props) > 0:
+            return super(BottomBar, self).update_style_properties(remaining_props)
 
 
 class Crumb(Widget):
@@ -274,20 +293,26 @@ class Crumb(Widget):
         self.animated.setup_next_animations(**self.settings)
         self.animated.mode = implicit.REPLACE
 
-        self._update_style_properties(self._style.get_items())
-
-    def _update_style_properties(self, props=None):
-        super(Crumb, self)._update_style_properties(props)
+        self.update_style_properties(self.style.get_items())
 
+    def update_style_properties(self, props=None):
         if props is None:
             return
 
+        remaining_props = {}
+
         for key, value in props.iteritems():
             if key == 'font-family':
                 self.text.font_family = value
             elif key == 'text-height':
                 self.text.height = value
                 self.text.y = (1.0-self.text.height)/2.0
+            else:
+                remaining_props[key] = value
+
+        if len(remaining_props) > 0:
+            return super(Crumb, self).update_style_properties(props)
+
 
 class BreadCrumbs(Widget):
     """
@@ -334,16 +359,16 @@ class BreadCrumbs(Widget):
         self.animated.setup_next_animations(**self.settings)
         self.animated.mode = implicit.REPLACE
 
-        self._update_style_properties(self._style.get_items())
-
-    def _update_style_properties(self, props=None):
-        super(BreadCrumbs, self)._update_style_properties(props)
+        self.update_style_properties(self.style.get_items())
 
+    def update_style_properties(self, props=None):
         if props is None:
             return
 
         theme = Theme.get_default()
 
+        remaining_props = {}
+
         for key, value in props.iteritems():
             if key == 'crumb-width':
                 self._crumb_width = value
@@ -359,6 +384,11 @@ class BreadCrumbs(Widget):
                 self.background.set_from_file(theme.get_resource(value))
             elif key == 'crumb-background':
                 self.master.set_from_file(theme.get_resource(value))
+            else:
+                remaining_props[key] = value
+
+        if len(remaining_props) > 0:
+            return super(BreadCrumbs, self).update_style_properties(remaining_props)
 
     def push_crumb(self, controller):
         if hasattr(controller, 'display_name'):
@@ -451,24 +481,28 @@ class TopBarWithBreadCrumbs(Widget):
         self.animated.setup_next_animations(**settings)
         self.animated.mode = implicit.REPLACE
         
-        self._update_style_properties(self._style.get_items())
-
-    def _update_style_properties(self, props=None):
-        super(TopBarWithBreadCrumbs, self)._update_style_properties(props)
+        self.update_style_properties(self.style.get_items())
 
+    def update_style_properties(self, props=None):
         if props is None:
             return
-        
+
+        remaining_props = props.copy()
         my_props = ['top-bar-height', 'bread-crumb-height']
         if set(my_props).issubset(props.keys()):
+            for key in my_props:
+                remaining_props.pop(key)
             self.topbar.height = props['top-bar-height']
             self.bread_crumb.height = props['bread-crumb-height']
 
             if self._display_bread_crumb == True:
                 self.bread_crumb.y = self.topbar.height
             else:
-                self.bread_crumb.y = self.topbar.height - value
-        
+                self.bread_crumb.y = self.topbar.height - self.bread_crumb.height
+
+        if len(remaining_props) > 0:
+            return super(TopBarWithBreadCrumbs, self).update_style_properties(remaining_props)
+
     def show_bread_crumb(self):
         self._display_bread_crumb = True
         self.bread_crumb.animated.y = self.topbar.height
@@ -642,7 +676,7 @@ class PoblesecBrowserController(BrowserController):
             controllers = self.frontend.retrieve_controllers('/poblesec')
             main = controllers[0]
             player = main.current_player.player
-            if len(player.playlist) > 0 and player.current_index != -1:
+            if len(player.playlist) > 0:
                 # switch only to the player if there is something to show/do
                 main.show_current_player()
                 player.play()
@@ -651,20 +685,20 @@ class PoblesecBrowserController(BrowserController):
             main = controllers[0]
             main.stop_all_players()
         elif index == bb.LIST:
-            # we assume current is a ListSwitcher
-            switcher = self.history.current
-            switcher.switch_mode(switcher.modes[0])
-            self.history.current.widget.focus = True
+            if isinstance(self.history.current, ListSwitcherController):
+                switcher = self.history.current
+                switcher.switch_mode(switcher.modes[0])
+                self.history.current.widget.focus = True
         elif index == bb.COVERF:
-            # we assume current is a ListSwitcher
-            switcher = self.history.current
-            switcher.switch_mode(switcher.modes[1])
-            self.history.current.widget.focus = True
+            if isinstance(self.history.current, ListSwitcherController):
+                switcher = self.history.current
+                switcher.switch_mode(switcher.modes[1])
+                self.history.current.widget.focus = True
         elif index == bb.GRID:
-            # we assume current is a ListSwitcher
-            switcher = self.history.current
-            switcher.switch_mode(switcher.modes[2])
-            self.history.current.widget.focus = True
+            if isinstance(self.history.current, ListSwitcherController):
+                switcher = self.history.current
+                switcher.switch_mode(switcher.modes[2])
+                self.history.current.widget.focus = True
 
     def handle_input(self, manager, input_event):
         button_bar = self.topbar_with_bread_crumb.topbar.button_bar
