@@ -28,25 +28,44 @@ from elisa.plugins.pigment.pigment_controller import PigmentController
 
 from elisa.plugins.poblesec.browser_controller import BrowserController
 
+import pkg_resources
+
 
 class FakeController(PigmentController):
     def handle_input(self, manager, input_event):
         pass
 
+
 class DummyController(PigmentController):
     pass
 
+
 class FakePluginRegistry(object):
     def create_component(self, *args, **kwargs):
         return defer.succeed(DummyController())
 
+    def get_enabled_plugins(self):
+        return ['elisa-plugin-poblesec']
+
+
+class FakeBus(object):
+    def register(self, callback, message_type):
+        pass
+
+
 class FakeApplication(object):
     config = Config()
+    bus = FakeBus()
     plugin_registry = FakePluginRegistry()
 
+    def log_failure(self, failure):
+        pass
+
+
 class BrokenFrontend(object):
     pass
 
+
 class FakeTransition(object):
     def __init__(self, broken=False):
         self._broken = broken
@@ -57,9 +76,11 @@ class FakeTransition(object):
         else:
             return defer.succeed(controller)
 
+
 class FakeManager(object):
     pass
 
+
 class FakeInputEvent(object):
     value = None
 
@@ -67,27 +88,46 @@ class FakeInputEvent(object):
 class TestBrowserController(TestCase):
 
     def setUp(self):
-        common.application = FakeApplication()
+        self._patch_application()
+        self._patch_dbus()
+
         self.frontend = PigmentFrontend()
+
+        # Load the controller and decorator mappings for poblesec
+        requirement = pkg_resources.Requirement.parse('elisa-plugin-poblesec')
+        poblesec = pkg_resources.working_set.find(requirement)
+        self.frontend.plugin_status_changed_cb(poblesec, True)
+
         self.frontend.add_controller("/fake/controller", FakeController)
         self.frontend.add_controller("/dummy/controller", DummyController)
-        # overwrite the DBus initialize
-        self._dbus_init = BrowserController._initialize_dbus
-        self._dbus_clean = BrowserController._clean_dbus
-        BrowserController._initialize_dbus = lambda x: x
-        BrowserController._clean_dbus = lambda x: x
-
         self.browser = BrowserController()
 
-
     def tearDown(self):
         def cleaned(result):
-            BrowserController._initialize_dbus = self._dbus_init
-            BrowserController._clean_dbus = self._dbus_clean
+            self._unpatch_dbus()
+            self._unpatch_application()
             return result
 
         return self.browser.clean().addCallback(cleaned)
 
+    def _patch_application(self):
+        self._old_application = common.application
+        common.application = FakeApplication()
+
+    def _unpatch_application(self):
+        common.application = self._old_application
+
+    def _patch_dbus(self):
+        # overwrite the DBus initialize
+        self._dbus_init = BrowserController._initialize_dbus
+        self._dbus_clean = BrowserController._clean_dbus
+        BrowserController._initialize_dbus = lambda *args: None
+        BrowserController._clean_dbus = lambda *args: None
+
+    def _unpatch_dbus(self):
+        BrowserController._initialize_dbus = self._dbus_init
+        BrowserController._clean_dbus = self._dbus_clean
+
     def test_initialize(self):
         self.browser.initialize()
         self.failUnlessEqual(self.browser._home_path, self.browser.default_config['home'])
@@ -233,4 +273,3 @@ class TestBrowserController(TestCase):
 #        dfr.addCallback(handle_input)
 #
 #        return dfr
-
