@@ -33,20 +33,36 @@ from elisa.plugins.poblesec.history import History
 class FakeController(PigmentController):
     pass
 
+
 class BadControllerError(Exception):
      pass
 
+
 class BadController(PigmentController):
     def __init__(self):
         super(BadController, self).__init__()
         raise BadControllerError
 
+
 class NeverEndingController(PigmentController):
     def initialize(self):
         return defer.Deferred()
 
+
+class FakeBus(object):
+    def register(self, callback, message_type):
+        pass
+
+
+class FakePluginRegistry(object):
+    def get_enabled_plugins(self):
+        return []
+
+
 class FakeApplication(object):
     config = Config()
+    bus = FakeBus()
+    plugin_registry = FakePluginRegistry()
 
     def __init__(self):
         self.log_failure_called = False
@@ -54,6 +70,7 @@ class FakeApplication(object):
     def log_failure(self, failure):
         self.log_failure_called = True
 
+
 class TestHistory(TestCase):
 
     def setUp(self):
@@ -155,9 +172,10 @@ class TestHistory(TestCase):
             self.failUnlessEqual(self.history.index, 0)
             self.failUnlessEqual(len(self.history._controllers), 1)
 
+            # you cannot go back if there would be no controllers left
             self.history.go_back()
-            self.failUnlessEqual(self.history.index, -1)
-            self.failUnlessEqual(len(self.history._controllers), 0)
+            self.failUnlessEqual(self.history.index, 0)
+            self.failUnlessEqual(len(self.history._controllers), 1)
 
         dfr.addCallback(checks)
 
@@ -167,29 +185,40 @@ class TestHistory(TestCase):
         self.history.frontend.add_controller("/neverending/controller", NeverEndingController)
         self.history.frontend.add_controller("/fake/controller", FakeController)
 
+        self.cancelled = False
+
         def on_cancel(*args):
             """catching the cancellation"""
+            self.cancelled = True
             self.failUnlessEqual(self.history.index, 0)
             self.failUnlessEqual(len(self.history._controllers), 1)
 
+        def check(result):
+            # the cancelled was actually called
+            self.assertTrue(self.cancelled)
+
         def next_append(res):
             path = "/neverending/controller"
             name = "NeverEnding"
+            # delay the go back, so that it would kill this new neverending
+            # controller
+            reactor.callLater(0, self.history.go_back)
+
             return self.history.append_controller(path, name)
-            
 
         dfr = self.history.append_controller("/fake/controller", "Fake")
         dfr.addCallback(next_append)
         dfr.addErrback(on_cancel)
 
-        self.history.go_back()
+        dfr.addCallback(check)
 
         return dfr
 
+    test_go_back_cancel.timeout = 4
+
     def test_go_back_void(self):
         self.history.go_back()
 
     def test_go_back_broken_current(self):
         self.history.current = "Hijacked"
         self.history.go_back()
-
