@@ -39,8 +39,6 @@ class TextButton(Widget):
     A simple button widget with only a text label.
     """
 
-    style_prefix = 'text-button'
-
     def __init__(self):
         super(TextButton, self).__init__()
 
@@ -52,54 +50,24 @@ class TextButton(Widget):
         self._background.bg_a = 0
         self._background.visible = True
 
-        self._text = Text()
-        self.add(self._text)
-        self._text.visible = True
+        self.text = Text()
+        self.add(self.text)
+        self.text.visible = True
 
-        self._update_style_properties(self._style.get_items())
-
-    def _update_style_properties(self, props=None):
-        super(TextButton, self)._update_style_properties(props)
-
-        if props is None:
-            return
-
-        for key, value in props.iteritems():
-            if key == '%s-width' % self.style_prefix:
-                self._text.width = value
-            elif key == '%s-height' % self.style_prefix:
-                self._text.height = value
-            elif key == '%s-x' % self.style_prefix:
-                self._text.x = value
-            elif key == '%s-y' % self.style_prefix:
-                self._text.y = value
-            elif key == '%s-z' % self.style_prefix:
-                self._text.z = value
-            elif key == '%s-alignment' % self.style_prefix:
-                self._text.alignment = eval('pgm.TEXT_ALIGN_%s' % \
-                                            value.upper())
-            elif key == '%s-ellipsize' % self.style_prefix:
-                self._text.ellipsize = eval('pgm.TEXT_ELLIPSIZE_%s' % \
-                                            value.upper())
-            elif key == '%s-weight' % self.style_prefix:
-                self._text.weight = eval('pgm.TEXT_WEIGHT_%s' % value.upper())
-            elif key == '%s-bg-a' % self.style_prefix:
-                self._text.bg_a = value
-            elif key == '%s-fg-color' % self.style_prefix:
-                self._text.fg_color = value
+        self.update_style_properties(self.style.get_items())
 
     def clean(self):
-        self._text.clean()
-        self._text = None
+        self.text.clean()
+        self.text = None
         self._background.clean()
         self._background = None
         return super(TextButton, self).clean()
 
     def label__get(self):
-        return self._text.label
+        return self.text.label
 
     def label__set(self, label):
-        self._text.label = label
+        self.text.label = label
 
     label = property(label__get, label__set)
 
@@ -217,8 +185,6 @@ class IconButton(Widget):
     A button widget with an icon and an optional text.
     """
 
-    style_prefix = 'icon-button'
-
     def __init__(self):
         super(IconButton, self).__init__()
 
@@ -230,12 +196,12 @@ class IconButton(Widget):
         self._background.bg_a = 0
         self._background.visible = True
 
-        self._container = HBox()
-        self.add(self._container, forward_signals=False)
-        self._container.visible = True
+        self.container = HBox()
+        self.add(self.container, forward_signals=False)
+        self.container.visible = True
 
         self.icon = Image()
-        self._container.pack_start(self.icon)
+        self.container.pack_start(self.icon)
         self.icon.layout = pgm.IMAGE_SCALED
         self.icon.bg_a = 0
         self.icon.visible = True
@@ -246,63 +212,52 @@ class IconButton(Widget):
         self.text.bg_a = 0
         self.text.visible = True
 
-        self._update_style_properties(self._style.get_items())
-
-    def _update_style_properties(self, props=None):
-        super(IconButton, self)._update_style_properties(props)
-
-        if props is None:
-            return
-
-        for key, value in props.iteritems():
-            if key == '%s-container-x' % self.style_prefix:
-                self._container.x = value
-            elif key == '%s-container-y' % self.style_prefix:
-                self._container.y = value
-            elif key == '%s-container-width' % self.style_prefix:
-                self._container.width = value
-            elif key == '%s-container-height' % self.style_prefix:
-                self._container.height = value
-            elif key == '%s-container-spacing' % self.style_prefix:
-                self._container.spacing = value
-            elif key == '%s-icon-only-width' % self.style_prefix:
-                self.icon.width = value
-            elif key == '%s-icon-with-text-width' % self.style_prefix:
-                self.icon.width = value
-            elif key == '%s-icon-height' % self.style_prefix:
-                self.icon.height = value
-            elif key == '%s-text-width' % self.style_prefix:
-                self.text.width = value
+        self.update_style_properties(self.style.get_items())
 
     def clean(self):
         try:
-            self._container.remove(self.text)
+            self.container.remove(self.text)
         except NodeNotInGroup:
             pass
-        self._container.remove(self.icon)
+        self.container.remove(self.icon)
         self.text.clean()
         self.text = None
         self.icon.clean()
         self.icon = None
-        self._container.clean()
-        self._container = None
+        self.container.clean()
+        self.container = None
         self._background.clean()
         self._background = None
         return super(IconButton, self).clean()
 
+    def update_style_properties(self, props=None):
+        if props is None:
+            return
+
+        remaining_props = props.copy()
+        custom_props = ('icon_only-width', 'icon_with_text-width')
+        for prop in custom_props:
+            try:
+                remaining_props.pop(prop)
+            except KeyError:
+                continue
+
+        if len(remaining_props) > 0:
+            return super(IconButton, self).update_style_properties(remaining_props)
+
     def _layout_text(self):
-        style = self._style.get_items()
+        style = self.style.get_items()
         if len(self.label) == 0:
             try:
-                self._container.remove(self.text)
-            except WidgetNotBoxedError:
+                self.container.remove(self.text)
+            except (WidgetNotBoxedError, NodeNotInGroup):
                 pass
-            self.icon.width = style['%s-icon-only-width' % self.style_prefix]
+            self.icon.width = style['icon_only-width']
         else:
-            if self.text not in self._container:
-                self._container.pack_start(self.text)
-            self.icon.width = style['%s-icon-with-text-width' % self.style_prefix]
-            self.text.width = style['%s-text-width' % self.style_prefix]
+            if self.text not in self.container:
+                self.container.pack_start(self.text)
+            self.icon.width = style['icon_with_text-width']
+            self.text.width = style['text-width']
 
     def label__get(self):
         return self.text.label
