@@ -23,7 +23,9 @@ import pgm
 from pgm.utils.image import cairo_gradient
 
 
-class ImageWithReflection(Widget, LoadableMixin):
+# we must inherit from LoadableMixin first because of
+# http://bugzilla.gnome.org/show_bug.cgi?id=554443
+class ImageWithReflection(LoadableMixin, Widget):
 
     loading_attribute = 'image'
 
