@@ -72,6 +72,7 @@ class PlayerStatusLabel(HBox):
 
 BARS = enum.Enum("SEEKING_BAR", "VOLUME_BAR", "BUFFERING_BAR")
 
+
 class ProgressBarCollection(VBox):
     """
     Collection of three progress bars:
@@ -82,17 +83,14 @@ class ProgressBarCollection(VBox):
     The widget contains the three progress bars and a 3 PlayerStatusLabel.
     Only one progress bar (and its label) is visible at the same moment.
     """
-    
-    def __init__(self):
-        super(ProgressBarCollection, self).__init__()
 
+    def create_widgets(self):
         # Group that contains the 3 progress bar
         self.bar_group = Widget()
         self.pack_start(self.bar_group)
         self.bar_group.position = (0.0, 0.0, 0.0)
-        self.bar_group.size = (0.60, 1.0)
         self.bar_group.visible = True
-        
+
         # Seeking progress bar
         self.seeking_bar = ProgressBar()
         self.seeking_bar._orientation = HORIZONTAL
@@ -103,7 +101,7 @@ class ProgressBarCollection(VBox):
         bg = SlicedImageHorizontal()
         self.seeking_bar.background = bg
         self.seeking_bar.visible = False
-        
+
         # Volume progress bar
         self.volume_bar = VolumeBar()
         self.volume_bar.visible = False
@@ -120,14 +118,13 @@ class ProgressBarCollection(VBox):
         self.buffering_bar.size = (1.0, 1.0)
         self.buffering_bar.visible = False
         self.buffering_bar.sensitive = False
-        
+
         # Group of PlayerStatusLabel, one for each progress bar
         self.label_group = Widget()
         self.pack_start(self.label_group)
-        self.bar_group.position = (0.0, 0.0, 0.0)
-        self.bar_group.size = (0.40, 1.0)
+        self.label_group.position = (0.0, 0.0, 0.0)
         self.label_group.visible = True
-        
+
         # PlayerStatusLabel for the seeking bar
         self.seeking_bar_label = PlayerStatusLabel()
         self.label_group.add(self.seeking_bar_label)
@@ -135,7 +132,7 @@ class ProgressBarCollection(VBox):
         self.seeking_bar_label.position = (0.0, 0.0, 0.0)
         self.seeking_bar_label.size = (1.0, 1.0)
         self.seeking_bar_label.visible = False
-        
+
         # PlayerStatusLabel for the volume bar
         self.volume_bar_label = Text()
         self.label_group.add(self.volume_bar_label)
@@ -143,7 +140,7 @@ class ProgressBarCollection(VBox):
         self.volume_bar_label.position = (0.0, 0.0, 0.0)
         self.volume_bar_label.size = (1.0, 1.0)
         self.volume_bar_label.visible = False
-        
+
         # PlayerStatusLabel for the buffering bar
         self.buffering_bar_label = Text()
         self.label_group.add(self.buffering_bar_label)
@@ -151,20 +148,19 @@ class ProgressBarCollection(VBox):
         self.buffering_bar_label.position = (0.0, 0.0, 0.0)
         self.buffering_bar_label.size = (1.0, 1.0)
         self.buffering_bar_label.visible = False
-        
+
         # By default, the seeking bar and it label are visible
         self._visible_bar = BARS.SEEKING_BAR
         self.set_visible_bar(self._visible_bar)
-        
-        self._update_status_style_properties(self._style.get_items())
-        
-    def _update_status_style_properties(self, props=None):
 
+    def update_style_properties(self, props=None):
         if props is None:
             return
-        
+
         theme = Theme.get_default()
-        
+
+        remaining_props = {}
+
         for key, value in props.iteritems():
             if key == 'osd-pbc-seeking-bar-bg-left':
                 filename = theme.get_resource(value)
@@ -181,12 +177,12 @@ class ProgressBarCollection(VBox):
             elif key == 'osd-pbc-seeking-bar-cursor-spacing-y':
                 self.seeking_bar.style.spacing_y = value
                 self.volume_bar.progressbar.style.spacing_y = value
-            elif key == 'osd-pbc-progress-bars-height':
-                self.bar_group.height = value
-            elif key == 'osd-pbc-player-status-height':
-                self.label_group.height = value
+            else:
+                remaining_props[key] = value
+
+        if len(remaining_props) > 0:
+            return super(ProgressBarCollection, self).update_style_properties(remaining_props)
 
-                
     def set_visible_bar(self, value):
         """
         Display a specific bar with the associated label
@@ -254,17 +250,17 @@ class ProgressBarCollection(VBox):
             self.volume_bar.progressbar.sensitive = value
             self.seeking_bar.sensitive = not value
 
+
 class StatusDisplayDetails(VBox):
+
     """
     right part of the status widget
     with the scroll bar, title, details and player status
     """
-    
-    def __init__(self):
-        super(StatusDisplayDetails, self).__init__()
 
+    def create_widgets(self):
         self.spacing = 0.01
-        
+
         # Title of the status box
         self.title = Text()
         self.title.weight = pgm.TEXT_WEIGHT_BOLD
@@ -273,7 +269,7 @@ class StatusDisplayDetails(VBox):
         self.pack_start(self.title)
         self.title.bg_color = (0, 0, 0, 0)
         self.title.visible = True
-        
+
         # details of the media in the status box line 1
         self.details = Text()
         self.details.label = ""
@@ -281,7 +277,7 @@ class StatusDisplayDetails(VBox):
         self.pack_start(self.details)
         self.details.bg_color = (0, 0, 0, 0)
         self.details.visible = True
-        
+
         # details of the media in the status box, line2
         self.details_2 = Text()
         self.details_2.label = ""
@@ -289,51 +285,44 @@ class StatusDisplayDetails(VBox):
         self.pack_start(self.details_2)
         self.details_2.bg_color = (0, 0, 0, 0)  
         self.details_2.visible = True
-        
+
         # empty space between the line 2 of the details and the seek bars
         self.status_empty_space = Image()
         self.pack_start(self.status_empty_space)
         self.status_empty_space.bg_color = (0, 0, 0, 0)   
         self.status_empty_space.visible = True
-        
+
         # Smart progress bar
         self.progress_bars = ProgressBarCollection()
         self.pack_start(self.progress_bars)
         self.progress_bars.visible = True
-        
+
         # Default values
         self.title.height = 0.20
         self.details.height = 0.20
         self.details_2.height = 0.20
         self.status_empty_space.height = 0.05
         self.progress_bars.height = 0.20
-        
-        self._update_status_style_properties(self._style.get_items())
-        
-    def _update_status_style_properties(self, props=None):
 
+    def update_style_properties(self, props=None):
         if props is None:
             return
-        
+
         theme = Theme.get_default()
-        
+
+        remaining_props = {}
+
         for key, value in props.iteritems():
-            if key == 'osd-details-title-height':
-                self.title.height = value
-            elif key == 'osd-details-details-height':
-                self.details.height = value
-            elif key == 'osd-details-details-2-height':
-                self.details_2.height = value
-            elif key == 'osd-details-empty-space-height':
-                self.status_empty_space.height = value
-            elif key == 'osd-details-progress-bars-height':
-                self.progress_bars.height = value
-            elif key == 'osd-details-font-family':
+            if key == 'osd-details-font-family':
                 self.title.font_family = value
                 self.details.font_family = value
                 self.details_2.font_family = value
-                self.player_status_right.font_family = value
-                self.player_status_left.font_family = value
+            else:
+                remaining_props[key] = value
+
+        if len(remaining_props) > 0:
+            return super(StatusDisplayDetails, self).update_style_properties(remaining_props)
+
 
 class StatusDisplay(HBox):
     """
@@ -365,16 +354,14 @@ class StatusDisplay(HBox):
         'volume-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
                            (gobject.TYPE_INT,)),
         }
-    
-    def __init__(self):
-        super(StatusDisplay, self).__init__()
-        
+
+    def create_widgets(self):
         # Default formated position of the seeking bar (used for display)
         self._formated_seeking_position = self._format_bar_position(0)
         self._formated_seeking_duration = self._format_bar_position(0)
         self._seeking_position = -1
         self.alignment = ALIGNMENT.START
-        
+
         # Default position of the volume bar
         self._volume_max = 0
         self._volume_position = 0
@@ -382,7 +369,7 @@ class StatusDisplay(HBox):
         # HBox initialization
         self.spacing = 0.01
         self.alignment = ALIGNMENT.START
-        
+
         # Image preview on the left
         self.preview = Image()
         self.pack_start(self.preview)
@@ -391,7 +378,7 @@ class StatusDisplay(HBox):
         self.preview.layout = pgm.IMAGE_SCALED
         self.preview.alignment = pgm.IMAGE_RIGHT
         self.preview.visible = True
-        
+
         # Details of the current file (bars, title, position...)
         self.status_display_details = StatusDisplayDetails()
         self.pack_start(self.status_display_details)
@@ -401,7 +388,7 @@ class StatusDisplay(HBox):
                                 ('index-changed', self._seeking_bar_index_cb)
         self.status_display_details.progress_bars.volume_bar.progressbar.connect \
                                 ('index-changed', self._volume_bar_index_cb)
-        
+
         # empty space. Needed for the picture case, the video case using all
         # the space
         self.right_empty_space = Image()
@@ -409,29 +396,26 @@ class StatusDisplay(HBox):
         self.right_empty_space.size = (0.30, 1.00)
         self.right_empty_space.bg_color = (0, 0, 0, 0)
         self.right_empty_space.visible = True
-        self._update_status_style_properties(self._style.get_items())        
         self._update_seeking_counter()
         self._update_volume_counter()
-        
-    def _update_status_style_properties(self, props=None):
-        super(StatusDisplay, self)._update_style_properties(props)
 
+    def _update_style_properties(self, props=None):
         if props is None:
             return
-        
+
+        remaining_props = {}
+
         for key, value in props.iteritems():
             if key == 'center-position':
+                # Unused?
                 self.preview.width = value
                 self.status_display_details.width = 1.0 - value
-            elif key == 'center-spacing':
-                self.spacing = value
-            elif key == 'preview-width':
-                self.preview.width = value
-            elif key == 'status-details-width':
-                self.status_display_details.width = value
-            elif key == 'status-left-empty-space':
-                self.right_empty_space.width = value
-                
+            else:
+                remaining_props[key] = value
+
+        if len(remaining_props) > 0:
+            return super(StatusDisplay, self).update_style_properties(remaining_props)
+
     def _format_bar_position(self, value):
         if value == -1:
             return 0
@@ -579,11 +563,15 @@ class VideoStatusDisplay(StatusDisplay):
     """
     
     factor = 100
-        
+
+    def __init__(self):
+        self._strfformat = "%H:%M:%S"
+        super(VideoStatusDisplay, self).__init__()
+
     def _format_bar_position(self, value):
         if value == -1:
-            return "00:00:00"
-        return time.strftime("%H:%M:%S", time.gmtime(value))
+            value = 0
+        return time.strftime(self._strfformat, time.gmtime(value))
         
     def set_seeking_position(self, value):
         """
@@ -603,7 +591,17 @@ class VideoStatusDisplay(StatusDisplay):
             self._seeking_position
             
         self._update_seeking_counter()
-            
+
+    def _recalculate_strfformat(self, value):
+        if value >= 3600:
+            self._strfformat = "%H:%M:%S"
+        elif value >= 60:
+            self._strfformat = "%M:%S"
+        elif value > 0:
+            self._strfformat = "%Ss"
+        else:
+            self._strfformat = ""
+
     def set_seeking_duration(self, value):
         """
         Set the duration of the video seeking bar
@@ -619,6 +617,8 @@ class VideoStatusDisplay(StatusDisplay):
             seeking_bar.visible = True
 
         seeking_bar.items_number =  value * self.factor
+
+        self._recalculate_strfformat(value)
         self._formated_seeking_duration = self._format_bar_position(value)
         self._update_seeking_counter()
         
