@@ -27,7 +27,7 @@ from elisa.core.common import application
 from elisa.plugins.pigment.widgets.widget import Widget
 from elisa.plugins.pigment.widgets.list_vertical import ListVertical
 from elisa.plugins.pigment.widgets.list_horizontal import ListHorizontal
-from elisa.plugins.pigment.widgets import notifying_list
+from elisa.core.utils import notifying_list
 from elisa.plugins.pigment.graph.image import Image
 from elisa.plugins.pigment.graph.text import Text
 
@@ -75,8 +75,6 @@ class SearchResultWidget(Widget):
     A widget used to display the contents of a L{SearchResultNode}.
     """
 
-    style_prefix = 'search-result'
-
     def __init__(self):
         super(SearchResultWidget, self).__init__()
 
@@ -98,51 +96,7 @@ class SearchResultWidget(Widget):
         self.add(self.total, forward_signals=False)
         self.total.visible = True
 
-        self._update_style_properties(self._style.get_items())
-
-    def _update_style_properties(self, props=None):
-        super(SearchResultWidget, self)._update_style_properties(props)
-
-        if props is None:
-            return
-
-        for key, value in props.iteritems():
-            if key == '%s-icon-x' % self.style_prefix:
-                self.icon.x = value
-            elif key == '%s-icon-y' % self.style_prefix:
-                self.icon.y = value
-            elif key == '%s-icon-height' % self.style_prefix:
-                self.icon.height = value
-            elif key == '%s-icon-alignment' % self.style_prefix:
-                self.icon.alignment = eval('pgm.IMAGE_%s' % value.upper())
-            elif key == '%s-icon-bga' % self.style_prefix:
-                self.icon.bg_a = value
-            elif key == '%s-label-x' % self.style_prefix:
-                self.label.x = value
-            elif key == '%s-label-y' % self.style_prefix:
-                self.label.y = value
-            elif key == '%s-label-height' % self.style_prefix:
-                self.label.height = value
-            elif key == '%s-label-ellipsize' % self.style_prefix:
-                self.label.ellipsize = eval('pgm.TEXT_ELLIPSIZE_%s' % value.upper())
-            elif key == '%s-label-bga' % self.style_prefix:
-                self.label.bg_a = value
-            elif key == '%s-label-fg-color' % self.style_prefix:
-                self.label.fg_color = value
-            elif key == '%s-total-x' % self.style_prefix:
-                self.total.x = value
-            elif key == '%s-total-y' % self.style_prefix:
-                self.total.y = value
-            elif key == '%s-total-width' % self.style_prefix:
-                self.total.width = value
-            elif key == '%s-total-height' % self.style_prefix:
-                self.total.height = value
-            elif key == '%s-total-alignment' % self.style_prefix:
-                self.total.alignment = eval('pgm.TEXT_ALIGN_%s' % value.upper())
-            elif key == '%s-total-bga' % self.style_prefix:
-                self.total.bg_a = value
-            elif key == '%s-total-fg-color' % self.style_prefix:
-                self.total.fg_color = value
+        self.update_style_properties(self.style.get_items())
 
     def clean(self):
 
@@ -189,7 +143,6 @@ class SearchResultEntryWidget(Widget):
     """
 
     item_widget_class = None
-    style_prefix = 'search-result-entry'
 
     def __init__(self):
         super(SearchResultEntryWidget, self).__init__()
@@ -238,62 +191,10 @@ class SearchResultEntryWidget(Widget):
         self._clicked_id = self.list.connect('item-clicked',
                                              self._item_clicked_cb)
 
-        self._update_style_properties(self._style.get_items())
-
-    def _update_style_properties(self, props=None):
-        super(SearchResultEntryWidget, self)._update_style_properties(props)
-
-        if props is None:
-            return
-
-        for key, value in props.iteritems():
-            if key == '%s-icon-x' % self.style_prefix:
-                self.icon.x = value
-            elif key == '%s-icon-y' % self.style_prefix:
-                self.icon.y = value
-            elif key == '%s-icon-width' % self.style_prefix:
-                self.icon.width = value
-            elif key == '%s-icon-height' % self.style_prefix:
-                self.icon.height = value
-            elif key == '%s-icon-layout' % self.style_prefix:
-                self.icon.layout = eval('pgm.IMAGE_%s' % value.upper())
-            elif key == '%s-icon-alignment' % self.style_prefix:
-                self.icon.alignment = eval('pgm.IMAGE_%s' % value.upper())
-            elif key == '%s-icon-bga' % self.style_prefix:
-                self.icon.bg_a = value
-            elif key == '%s-label-x' % self.style_prefix:
-                self.label.x = value
-            elif key == '%s-label-y' % self.style_prefix:
-                self.label.y = value
-            elif key == '%s-label-width' % self.style_prefix:
-                self.label.width = value
-            elif key == '%s-label-height' % self.style_prefix:
-                self.label.height = value
-            elif key == '%s-label-ellipsize' % self.style_prefix:
-                self.label.ellipsize = eval('pgm.TEXT_ELLIPSIZE_%s' % value.upper())
-            elif key == '%s-label-bga' % self.style_prefix:
-                self.label.bg_a = value
-            elif key == '%s-label-fg-color' % self.style_prefix:
-                self.label.fg_color = value
-            elif key == '%s-loading-x' % self.style_prefix:
-                self.loading_animation.x = value
-            elif key == '%s-loading-y' % self.style_prefix:
-                self.loading_animation.y = value
-            elif key == '%s-loading-width' % self.style_prefix:
-                self.loading_animation.width = value
-            elif key == '%s-loading-height' % self.style_prefix:
-                self.loading_animation.height = value
-            elif key == '%s-list-x' % self.style_prefix:
-                self.list.x = value
-            elif key == '%s-list-y' % self.style_prefix:
-                self.list.y = value
-            elif key == '%s-list-width' % self.style_prefix:
-                self.list.width = value
-            elif key == '%s-list-height' % self.style_prefix:
-                self.list.height = value
+        self.update_style_properties(self.style.get_items())
 
     def clean(self):
-        self.disconnect(self._clicked_id)
+        self.list.disconnect(self._clicked_id)
 
         self.icon.clean()
         self.icon = None
@@ -452,6 +353,15 @@ class SearchResultsWidget(ListHorizontal):
         self._selected_id = self.connect('selected-item-changed',
                                          self._selected_item_changed_cb)
 
+
+    def _emit_item_clicked(self, widget, *args):
+        super(SearchResultsWidget, self)._emit_item_clicked(widget, *args)
+
+        # FIXME: because I am a ListHorizontal, containing other List
+        # instances deep inside me, I want to forward the item-clicked
+        # signal to my buddies so that they can deal with it. So this
+        # _emit_item_clicked returns nothing.
+
     def clean(self):
         self.disconnect(self._selected_id)
         return super(SearchResultsWidget, self).clean()
