@@ -14,10 +14,10 @@
 # See "LICENSE.Elisa" in the root directory of this distribution package
 # for details on that license.
 #
-# Author: Benjamin Kampann <benjamin@fluendo.com>
+# Author: Benjamin Kampmann <benjamin@fluendo.com>
 
 """
-The implementation of a merging search engine for elisa
+The implementation of a merging search engine for elisa.
 """
 
 from elisa.core.components.resource_provider import ResourceProvider
@@ -31,20 +31,23 @@ from elisa.plugins.search.models import MusicSearchResultModel, \
 
 import pkg_resources
 
+
 SEARCH_PATH_TO_MODEL = {'music' : MusicSearchResultModel,
                         'videos': VideosSearchResultModel}
 
+
 class SearchMetaresourceProvider(ResourceProvider):
 
     # the entry point to find the 'Searchers'
     entry_point = 'elisa.plugins.search.searchers'
 
-    supported_uri = '^elisa://search/.*'
+    supported_uri = '^elisa://search/(%s).*' % \
+            '|'.join(SEARCH_PATH_TO_MODEL.keys())
 
     default_config = {'default_searcher' : 'DBSearcher'}
     config_doc = {'default_searcher':
-                  'The default searcher is the searcher that is always' \
-                  ' asked first for the search result and fills the reference' \
+                  'The default searcher is the searcher that is always ' \
+                  'asked first for the search result and fills the reference' \
                   ' model with data' }
 
     def __init__(self):
@@ -237,4 +240,3 @@ class SearchMetaresourceProvider(ResourceProvider):
         dfr = super(SearchMetaresourceProvider, self).clean()
         dfr.addCallback(self._clean_searchers)
         return dfr
-
