@@ -14,9 +14,7 @@
 # See "LICENSE.Elisa" in the root directory of this distribution package
 # for details on that license.
 #
-# Author: Benjamin Kampann <benjamin@fluendo.com>
-
-
+# Author: Benjamin Kampmann <benjamin@fluendo.com>
 
 from elisa.plugins.search.search_metaresource_provider import SearchMetaresourceProvider
 from elisa.plugins.search.searcher import Searcher
@@ -33,6 +31,7 @@ class TestUris(GenericSetup, UriRegExpTester, TestCase):
     working_uris = [ 'elisa://search/music',
                      'elisa://search/music/madonna?filter=artist',
                      'elisa://search/music/music?filter=albums',
+                     'elisa://search/videos/water?filter=title',
                      'elisa://search/music/water?filter=albums,artists,tracks']
     failing_uris = ['elisa:///', 'elisa://', 'elisa://search_something/',
                     'elisas://search/', 'elisa://search/pictures',
