@@ -23,7 +23,11 @@ from twisted.internet import defer
 
 from elisa.core import common
 from elisa.core.media_uri import MediaUri
-from elisa.plugins.wmd.wmd_resource import WMDResource
+try:
+    from elisa.plugins.wmd.wmd_resource import WMDResource
+except ImportError:
+    WMDResource = None
+
 from elisa.plugins.base.models.device import VolumeModel, DevicesModel
 
 class WMDMixin(object):
@@ -33,6 +37,9 @@ class WMDMixin(object):
     """
 
     def setUp(self):
+        if WMDResource is None:
+            self._platform_check()
+
         self.supported_protocols = ('file', 'cdda', 'ipod')
 
         def created(resource):
@@ -57,6 +64,11 @@ class WMDMixin(object):
 
         return WMDResource.create({}).addCallback(created)
 
+    def _platform_check(self):
+        import platform
+        if platform.system().lower() != 'Windows':
+            raise SkipTest("This test is only working on Windows")
+
     def tearDown(self):
         common.application = self.app
         return self.resource.clean()
