@@ -241,7 +241,8 @@ class WMDResource(ResourceProvider):
         except pywintypes.error, exception:
             if exception[0] in (winerror.ERROR_NOT_READY,
                                 winerror.ERROR_UNRECOGNIZED_VOLUME,
-                                winerror.ERROR_INVALID_PARAMETER):
+                                winerror.ERROR_INVALID_PARAMETER,
+                                winerror.ERROR_INVALID_HANDLE):
                 return None
             else:
                 raise
